# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['InstanceArgs', 'Instance']

@pulumi.input_type
class InstanceArgs:
    def __init__(__self__, *,
                 payment_type: pulumi.Input[str],
                 version_code: pulumi.Input[str],
                 buy_number: Optional[pulumi.Input[str]] = None,
                 container_image_scan: Optional[pulumi.Input[str]] = None,
                 container_image_scan_new: Optional[pulumi.Input[str]] = None,
                 honeypot: Optional[pulumi.Input[str]] = None,
                 honeypot_switch: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 rasp_count: Optional[pulumi.Input[str]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_period_unit: Optional[pulumi.Input[str]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 sas_anti_ransomware: Optional[pulumi.Input[str]] = None,
                 sas_cspm: Optional[pulumi.Input[str]] = None,
                 sas_cspm_switch: Optional[pulumi.Input[str]] = None,
                 sas_sc: Optional[pulumi.Input[bool]] = None,
                 sas_sdk: Optional[pulumi.Input[str]] = None,
                 sas_sdk_switch: Optional[pulumi.Input[str]] = None,
                 sas_sls_storage: Optional[pulumi.Input[str]] = None,
                 sas_webguard_boolean: Optional[pulumi.Input[str]] = None,
                 sas_webguard_order_num: Optional[pulumi.Input[str]] = None,
                 threat_analysis: Optional[pulumi.Input[str]] = None,
                 threat_analysis_flow: Optional[pulumi.Input[str]] = None,
                 threat_analysis_sls_storage: Optional[pulumi.Input[str]] = None,
                 threat_analysis_switch: Optional[pulumi.Input[str]] = None,
                 threat_analysis_switch1: Optional[pulumi.Input[str]] = None,
                 v_core: Optional[pulumi.Input[str]] = None,
                 vul_count: Optional[pulumi.Input[str]] = None,
                 vul_switch: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Instance resource.
        :param pulumi.Input[str] payment_type: The payment type of the resource
        :param pulumi.Input[str] version_code: Select the security center version. Value:
               - level7: Antivirus Edition.
               - level3: Premium version.
               - level2: Enterprise Edition.
               - level8: Ultimate.
               - level10: Purchase value-added services only.
        :param pulumi.Input[str] buy_number: Number of servers.
        :param pulumi.Input[str] container_image_scan: Container Image security scan. Interval type, value interval:[0,200000].
               
               > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        :param pulumi.Input[str] container_image_scan_new: Container Image security scan. Interval type, value interval:[0,200000].
               
               > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        :param pulumi.Input[str] honeypot: Number of cloud honeypot licenses. Interval type, value interval:[20,500].
               
               > **NOTE:**  This module can only be purchased when honeypot_switch = 1, starting with 20.
        :param pulumi.Input[str] honeypot_switch: Cloud honeypot. Value:
               - 1: Yes.
               - 2: No.
        :param pulumi.Input[str] modify_type: Change configuration type, value
               - Upgrade: Upgrade.
               - Downgrade: Downgrade.
        :param pulumi.Input[int] period: Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.
               
               > **NOTE:**  must be set when creating a prepaid instance.
        :param pulumi.Input[str] rasp_count: Number of application protection licenses. Interval type, value interval:[1,100000000].
        :param pulumi.Input[int] renew_period: Automatic renewal cycle, in months.
               
               > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        :param pulumi.Input[str] renewal_period_unit: Automatic renewal period unit, value:
               - M: month.
               - Y: years.
               
               > **NOTE:**  Must be set when RenewalStatus = AutoRenewal.
        :param pulumi.Input[str] renewal_status: Automatic renewal status, value:
               - AutoRenewal: automatic renewal.
               - ManualRenewal: manual renewal.
               
               Default ManualRenewal.
        :param pulumi.Input[str] sas_anti_ransomware: Anti-ransomware capacity. Unit: GB. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_cspm: Cloud platform configuration check scan times, interval type, value range:[15000,9999999999].
               
               > **NOTE:**  You must have sas_cspm_switch = 1 to purchase this module. The step size is 55000, that is, only multiples of 55000 can be filled in.
        :param pulumi.Input[str] sas_cspm_switch: Cloud platform configuration check switch. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[bool] sas_sc: Security screen. Value:
               - true: Yes.
               - false: No.
        :param pulumi.Input[str] sas_sdk: Number of malicious file detections. Unit: 10,000 times. Interval type, value interval:[10,9999999999].
               
               > **NOTE:**  This module can only be purchased when sas_sdk_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_sdk_switch: Malicious file detection SDK.
        :param pulumi.Input[str] sas_sls_storage: Log analysis storage capacity. Unit: GB. Interval type, value interval:[0,600000].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_webguard_boolean: Web tamper-proof switch. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[str] sas_webguard_order_num: Tamper-proof authorization number. Value:
               - 0: No
               - 1: Yes.
        :param pulumi.Input[str] threat_analysis: Threat Analysis log storage capacity. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  This module can only be purchased when Threat_analysis_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] threat_analysis_flow: Threat analysis and response log access traffic. After ThreatAnalysisSwitch1 is selected, it must be selected. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  Step size is 1.
        :param pulumi.Input[str] threat_analysis_sls_storage: Threat analysis and response log storage capacity. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] threat_analysis_switch: Threat analysis. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[str] threat_analysis_switch1: Threat analysis and response switch (new), values:
               - 0: No
               - 1: Yes
        :param pulumi.Input[str] v_core: Number of cores.
        :param pulumi.Input[str] vul_count: Vulnerability repair times, interval type, value range:[20,100000000].
               
               > **NOTE:**  This module can only be purchased when vul_switch = 1. Only when the version_code value is level7 or level10. other versions do not need to be purchased separately.
        :param pulumi.Input[str] vul_switch: Vulnerability fix switch. Value:
               - 0: No.
               - 1: Yes.
               
               > **NOTE:**  When the value of version_code is level7 or level10, the purchase is allowed. Other versions do not need to be purchased separately.
        """
        pulumi.set(__self__, "payment_type", payment_type)
        pulumi.set(__self__, "version_code", version_code)
        if buy_number is not None:
            pulumi.set(__self__, "buy_number", buy_number)
        if container_image_scan is not None:
            warnings.warn("""Field 'container_image_scan' has been deprecated from provider version 1.212.0. Container Image security scan. Interval type, value interval:[0,200000].> The step size is 20, that is, only multiples of 20 can be filled in.""", DeprecationWarning)
            pulumi.log.warn("""container_image_scan is deprecated: Field 'container_image_scan' has been deprecated from provider version 1.212.0. Container Image security scan. Interval type, value interval:[0,200000].> The step size is 20, that is, only multiples of 20 can be filled in.""")
        if container_image_scan is not None:
            pulumi.set(__self__, "container_image_scan", container_image_scan)
        if container_image_scan_new is not None:
            pulumi.set(__self__, "container_image_scan_new", container_image_scan_new)
        if honeypot is not None:
            pulumi.set(__self__, "honeypot", honeypot)
        if honeypot_switch is not None:
            pulumi.set(__self__, "honeypot_switch", honeypot_switch)
        if modify_type is not None:
            pulumi.set(__self__, "modify_type", modify_type)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if rasp_count is not None:
            pulumi.set(__self__, "rasp_count", rasp_count)
        if renew_period is not None:
            pulumi.set(__self__, "renew_period", renew_period)
        if renewal_period_unit is not None:
            pulumi.set(__self__, "renewal_period_unit", renewal_period_unit)
        if renewal_status is not None:
            pulumi.set(__self__, "renewal_status", renewal_status)
        if sas_anti_ransomware is not None:
            pulumi.set(__self__, "sas_anti_ransomware", sas_anti_ransomware)
        if sas_cspm is not None:
            pulumi.set(__self__, "sas_cspm", sas_cspm)
        if sas_cspm_switch is not None:
            pulumi.set(__self__, "sas_cspm_switch", sas_cspm_switch)
        if sas_sc is not None:
            pulumi.set(__self__, "sas_sc", sas_sc)
        if sas_sdk is not None:
            pulumi.set(__self__, "sas_sdk", sas_sdk)
        if sas_sdk_switch is not None:
            pulumi.set(__self__, "sas_sdk_switch", sas_sdk_switch)
        if sas_sls_storage is not None:
            pulumi.set(__self__, "sas_sls_storage", sas_sls_storage)
        if sas_webguard_boolean is not None:
            pulumi.set(__self__, "sas_webguard_boolean", sas_webguard_boolean)
        if sas_webguard_order_num is not None:
            pulumi.set(__self__, "sas_webguard_order_num", sas_webguard_order_num)
        if threat_analysis is not None:
            pulumi.set(__self__, "threat_analysis", threat_analysis)
        if threat_analysis_flow is not None:
            pulumi.set(__self__, "threat_analysis_flow", threat_analysis_flow)
        if threat_analysis_sls_storage is not None:
            pulumi.set(__self__, "threat_analysis_sls_storage", threat_analysis_sls_storage)
        if threat_analysis_switch is not None:
            pulumi.set(__self__, "threat_analysis_switch", threat_analysis_switch)
        if threat_analysis_switch1 is not None:
            pulumi.set(__self__, "threat_analysis_switch1", threat_analysis_switch1)
        if v_core is not None:
            pulumi.set(__self__, "v_core", v_core)
        if vul_count is not None:
            pulumi.set(__self__, "vul_count", vul_count)
        if vul_switch is not None:
            pulumi.set(__self__, "vul_switch", vul_switch)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[str]:
        """
        The payment type of the resource
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter(name="versionCode")
    def version_code(self) -> pulumi.Input[str]:
        """
        Select the security center version. Value:
        - level7: Antivirus Edition.
        - level3: Premium version.
        - level2: Enterprise Edition.
        - level8: Ultimate.
        - level10: Purchase value-added services only.
        """
        return pulumi.get(self, "version_code")

    @version_code.setter
    def version_code(self, value: pulumi.Input[str]):
        pulumi.set(self, "version_code", value)

    @property
    @pulumi.getter(name="buyNumber")
    def buy_number(self) -> Optional[pulumi.Input[str]]:
        """
        Number of servers.
        """
        return pulumi.get(self, "buy_number")

    @buy_number.setter
    def buy_number(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "buy_number", value)

    @property
    @pulumi.getter(name="containerImageScan")
    @_utilities.deprecated("""Field 'container_image_scan' has been deprecated from provider version 1.212.0. Container Image security scan. Interval type, value interval:[0,200000].> The step size is 20, that is, only multiples of 20 can be filled in.""")
    def container_image_scan(self) -> Optional[pulumi.Input[str]]:
        """
        Container Image security scan. Interval type, value interval:[0,200000].

        > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        """
        return pulumi.get(self, "container_image_scan")

    @container_image_scan.setter
    def container_image_scan(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "container_image_scan", value)

    @property
    @pulumi.getter(name="containerImageScanNew")
    def container_image_scan_new(self) -> Optional[pulumi.Input[str]]:
        """
        Container Image security scan. Interval type, value interval:[0,200000].

        > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        """
        return pulumi.get(self, "container_image_scan_new")

    @container_image_scan_new.setter
    def container_image_scan_new(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "container_image_scan_new", value)

    @property
    @pulumi.getter
    def honeypot(self) -> Optional[pulumi.Input[str]]:
        """
        Number of cloud honeypot licenses. Interval type, value interval:[20,500].

        > **NOTE:**  This module can only be purchased when honeypot_switch = 1, starting with 20.
        """
        return pulumi.get(self, "honeypot")

    @honeypot.setter
    def honeypot(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "honeypot", value)

    @property
    @pulumi.getter(name="honeypotSwitch")
    def honeypot_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Cloud honeypot. Value:
        - 1: Yes.
        - 2: No.
        """
        return pulumi.get(self, "honeypot_switch")

    @honeypot_switch.setter
    def honeypot_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "honeypot_switch", value)

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> Optional[pulumi.Input[str]]:
        """
        Change configuration type, value
        - Upgrade: Upgrade.
        - Downgrade: Downgrade.
        """
        return pulumi.get(self, "modify_type")

    @modify_type.setter
    def modify_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "modify_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.

        > **NOTE:**  must be set when creating a prepaid instance.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="raspCount")
    def rasp_count(self) -> Optional[pulumi.Input[str]]:
        """
        Number of application protection licenses. Interval type, value interval:[1,100000000].
        """
        return pulumi.get(self, "rasp_count")

    @rasp_count.setter
    def rasp_count(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rasp_count", value)

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> Optional[pulumi.Input[int]]:
        """
        Automatic renewal cycle, in months.

        > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        """
        return pulumi.get(self, "renew_period")

    @renew_period.setter
    def renew_period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "renew_period", value)

    @property
    @pulumi.getter(name="renewalPeriodUnit")
    def renewal_period_unit(self) -> Optional[pulumi.Input[str]]:
        """
        Automatic renewal period unit, value:
        - M: month.
        - Y: years.

        > **NOTE:**  Must be set when RenewalStatus = AutoRenewal.
        """
        return pulumi.get(self, "renewal_period_unit")

    @renewal_period_unit.setter
    def renewal_period_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_period_unit", value)

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> Optional[pulumi.Input[str]]:
        """
        Automatic renewal status, value:
        - AutoRenewal: automatic renewal.
        - ManualRenewal: manual renewal.

        Default ManualRenewal.
        """
        return pulumi.get(self, "renewal_status")

    @renewal_status.setter
    def renewal_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_status", value)

    @property
    @pulumi.getter(name="sasAntiRansomware")
    def sas_anti_ransomware(self) -> Optional[pulumi.Input[str]]:
        """
        Anti-ransomware capacity. Unit: GB. Interval type, value interval:[0,9999999999].

        > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "sas_anti_ransomware")

    @sas_anti_ransomware.setter
    def sas_anti_ransomware(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_anti_ransomware", value)

    @property
    @pulumi.getter(name="sasCspm")
    def sas_cspm(self) -> Optional[pulumi.Input[str]]:
        """
        Cloud platform configuration check scan times, interval type, value range:[15000,9999999999].

        > **NOTE:**  You must have sas_cspm_switch = 1 to purchase this module. The step size is 55000, that is, only multiples of 55000 can be filled in.
        """
        return pulumi.get(self, "sas_cspm")

    @sas_cspm.setter
    def sas_cspm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_cspm", value)

    @property
    @pulumi.getter(name="sasCspmSwitch")
    def sas_cspm_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Cloud platform configuration check switch. Value:
        - 0: No.
        - 1: Yes.
        """
        return pulumi.get(self, "sas_cspm_switch")

    @sas_cspm_switch.setter
    def sas_cspm_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_cspm_switch", value)

    @property
    @pulumi.getter(name="sasSc")
    def sas_sc(self) -> Optional[pulumi.Input[bool]]:
        """
        Security screen. Value:
        - true: Yes.
        - false: No.
        """
        return pulumi.get(self, "sas_sc")

    @sas_sc.setter
    def sas_sc(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sas_sc", value)

    @property
    @pulumi.getter(name="sasSdk")
    def sas_sdk(self) -> Optional[pulumi.Input[str]]:
        """
        Number of malicious file detections. Unit: 10,000 times. Interval type, value interval:[10,9999999999].

        > **NOTE:**  This module can only be purchased when sas_sdk_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "sas_sdk")

    @sas_sdk.setter
    def sas_sdk(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_sdk", value)

    @property
    @pulumi.getter(name="sasSdkSwitch")
    def sas_sdk_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Malicious file detection SDK.
        """
        return pulumi.get(self, "sas_sdk_switch")

    @sas_sdk_switch.setter
    def sas_sdk_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_sdk_switch", value)

    @property
    @pulumi.getter(name="sasSlsStorage")
    def sas_sls_storage(self) -> Optional[pulumi.Input[str]]:
        """
        Log analysis storage capacity. Unit: GB. Interval type, value interval:[0,600000].

        > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "sas_sls_storage")

    @sas_sls_storage.setter
    def sas_sls_storage(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_sls_storage", value)

    @property
    @pulumi.getter(name="sasWebguardBoolean")
    def sas_webguard_boolean(self) -> Optional[pulumi.Input[str]]:
        """
        Web tamper-proof switch. Value:
        - 0: No.
        - 1: Yes.
        """
        return pulumi.get(self, "sas_webguard_boolean")

    @sas_webguard_boolean.setter
    def sas_webguard_boolean(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_webguard_boolean", value)

    @property
    @pulumi.getter(name="sasWebguardOrderNum")
    def sas_webguard_order_num(self) -> Optional[pulumi.Input[str]]:
        """
        Tamper-proof authorization number. Value:
        - 0: No
        - 1: Yes.
        """
        return pulumi.get(self, "sas_webguard_order_num")

    @sas_webguard_order_num.setter
    def sas_webguard_order_num(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_webguard_order_num", value)

    @property
    @pulumi.getter(name="threatAnalysis")
    def threat_analysis(self) -> Optional[pulumi.Input[str]]:
        """
        Threat Analysis log storage capacity. Interval type, value interval:[0,9999999999].

        > **NOTE:**  This module can only be purchased when Threat_analysis_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "threat_analysis")

    @threat_analysis.setter
    def threat_analysis(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "threat_analysis", value)

    @property
    @pulumi.getter(name="threatAnalysisFlow")
    def threat_analysis_flow(self) -> Optional[pulumi.Input[str]]:
        """
        Threat analysis and response log access traffic. After ThreatAnalysisSwitch1 is selected, it must be selected. Interval type, value interval:[0,9999999999].

        > **NOTE:**  Step size is 1.
        """
        return pulumi.get(self, "threat_analysis_flow")

    @threat_analysis_flow.setter
    def threat_analysis_flow(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "threat_analysis_flow", value)

    @property
    @pulumi.getter(name="threatAnalysisSlsStorage")
    def threat_analysis_sls_storage(self) -> Optional[pulumi.Input[str]]:
        """
        Threat analysis and response log storage capacity. Interval type, value interval:[0,9999999999].

        > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "threat_analysis_sls_storage")

    @threat_analysis_sls_storage.setter
    def threat_analysis_sls_storage(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "threat_analysis_sls_storage", value)

    @property
    @pulumi.getter(name="threatAnalysisSwitch")
    def threat_analysis_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Threat analysis. Value:
        - 0: No.
        - 1: Yes.
        """
        return pulumi.get(self, "threat_analysis_switch")

    @threat_analysis_switch.setter
    def threat_analysis_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "threat_analysis_switch", value)

    @property
    @pulumi.getter(name="threatAnalysisSwitch1")
    def threat_analysis_switch1(self) -> Optional[pulumi.Input[str]]:
        """
        Threat analysis and response switch (new), values:
        - 0: No
        - 1: Yes
        """
        return pulumi.get(self, "threat_analysis_switch1")

    @threat_analysis_switch1.setter
    def threat_analysis_switch1(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "threat_analysis_switch1", value)

    @property
    @pulumi.getter(name="vCore")
    def v_core(self) -> Optional[pulumi.Input[str]]:
        """
        Number of cores.
        """
        return pulumi.get(self, "v_core")

    @v_core.setter
    def v_core(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "v_core", value)

    @property
    @pulumi.getter(name="vulCount")
    def vul_count(self) -> Optional[pulumi.Input[str]]:
        """
        Vulnerability repair times, interval type, value range:[20,100000000].

        > **NOTE:**  This module can only be purchased when vul_switch = 1. Only when the version_code value is level7 or level10. other versions do not need to be purchased separately.
        """
        return pulumi.get(self, "vul_count")

    @vul_count.setter
    def vul_count(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vul_count", value)

    @property
    @pulumi.getter(name="vulSwitch")
    def vul_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Vulnerability fix switch. Value:
        - 0: No.
        - 1: Yes.

        > **NOTE:**  When the value of version_code is level7 or level10, the purchase is allowed. Other versions do not need to be purchased separately.
        """
        return pulumi.get(self, "vul_switch")

    @vul_switch.setter
    def vul_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vul_switch", value)


@pulumi.input_type
class _InstanceState:
    def __init__(__self__, *,
                 buy_number: Optional[pulumi.Input[str]] = None,
                 container_image_scan: Optional[pulumi.Input[str]] = None,
                 container_image_scan_new: Optional[pulumi.Input[str]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 honeypot: Optional[pulumi.Input[str]] = None,
                 honeypot_switch: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 rasp_count: Optional[pulumi.Input[str]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_period_unit: Optional[pulumi.Input[str]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 sas_anti_ransomware: Optional[pulumi.Input[str]] = None,
                 sas_cspm: Optional[pulumi.Input[str]] = None,
                 sas_cspm_switch: Optional[pulumi.Input[str]] = None,
                 sas_sc: Optional[pulumi.Input[bool]] = None,
                 sas_sdk: Optional[pulumi.Input[str]] = None,
                 sas_sdk_switch: Optional[pulumi.Input[str]] = None,
                 sas_sls_storage: Optional[pulumi.Input[str]] = None,
                 sas_webguard_boolean: Optional[pulumi.Input[str]] = None,
                 sas_webguard_order_num: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None,
                 threat_analysis: Optional[pulumi.Input[str]] = None,
                 threat_analysis_flow: Optional[pulumi.Input[str]] = None,
                 threat_analysis_sls_storage: Optional[pulumi.Input[str]] = None,
                 threat_analysis_switch: Optional[pulumi.Input[str]] = None,
                 threat_analysis_switch1: Optional[pulumi.Input[str]] = None,
                 v_core: Optional[pulumi.Input[str]] = None,
                 version_code: Optional[pulumi.Input[str]] = None,
                 vul_count: Optional[pulumi.Input[str]] = None,
                 vul_switch: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Instance resources.
        :param pulumi.Input[str] buy_number: Number of servers.
        :param pulumi.Input[str] container_image_scan: Container Image security scan. Interval type, value interval:[0,200000].
               
               > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        :param pulumi.Input[str] container_image_scan_new: Container Image security scan. Interval type, value interval:[0,200000].
               
               > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] honeypot: Number of cloud honeypot licenses. Interval type, value interval:[20,500].
               
               > **NOTE:**  This module can only be purchased when honeypot_switch = 1, starting with 20.
        :param pulumi.Input[str] honeypot_switch: Cloud honeypot. Value:
               - 1: Yes.
               - 2: No.
        :param pulumi.Input[str] modify_type: Change configuration type, value
               - Upgrade: Upgrade.
               - Downgrade: Downgrade.
        :param pulumi.Input[str] payment_type: The payment type of the resource
        :param pulumi.Input[int] period: Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.
               
               > **NOTE:**  must be set when creating a prepaid instance.
        :param pulumi.Input[str] rasp_count: Number of application protection licenses. Interval type, value interval:[1,100000000].
        :param pulumi.Input[int] renew_period: Automatic renewal cycle, in months.
               
               > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        :param pulumi.Input[str] renewal_period_unit: Automatic renewal period unit, value:
               - M: month.
               - Y: years.
               
               > **NOTE:**  Must be set when RenewalStatus = AutoRenewal.
        :param pulumi.Input[str] renewal_status: Automatic renewal status, value:
               - AutoRenewal: automatic renewal.
               - ManualRenewal: manual renewal.
               
               Default ManualRenewal.
        :param pulumi.Input[str] sas_anti_ransomware: Anti-ransomware capacity. Unit: GB. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_cspm: Cloud platform configuration check scan times, interval type, value range:[15000,9999999999].
               
               > **NOTE:**  You must have sas_cspm_switch = 1 to purchase this module. The step size is 55000, that is, only multiples of 55000 can be filled in.
        :param pulumi.Input[str] sas_cspm_switch: Cloud platform configuration check switch. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[bool] sas_sc: Security screen. Value:
               - true: Yes.
               - false: No.
        :param pulumi.Input[str] sas_sdk: Number of malicious file detections. Unit: 10,000 times. Interval type, value interval:[10,9999999999].
               
               > **NOTE:**  This module can only be purchased when sas_sdk_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_sdk_switch: Malicious file detection SDK.
        :param pulumi.Input[str] sas_sls_storage: Log analysis storage capacity. Unit: GB. Interval type, value interval:[0,600000].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_webguard_boolean: Web tamper-proof switch. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[str] sas_webguard_order_num: Tamper-proof authorization number. Value:
               - 0: No
               - 1: Yes.
        :param pulumi.Input[str] status: The status of the resource
        :param pulumi.Input[str] threat_analysis: Threat Analysis log storage capacity. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  This module can only be purchased when Threat_analysis_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] threat_analysis_flow: Threat analysis and response log access traffic. After ThreatAnalysisSwitch1 is selected, it must be selected. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  Step size is 1.
        :param pulumi.Input[str] threat_analysis_sls_storage: Threat analysis and response log storage capacity. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] threat_analysis_switch: Threat analysis. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[str] threat_analysis_switch1: Threat analysis and response switch (new), values:
               - 0: No
               - 1: Yes
        :param pulumi.Input[str] v_core: Number of cores.
        :param pulumi.Input[str] version_code: Select the security center version. Value:
               - level7: Antivirus Edition.
               - level3: Premium version.
               - level2: Enterprise Edition.
               - level8: Ultimate.
               - level10: Purchase value-added services only.
        :param pulumi.Input[str] vul_count: Vulnerability repair times, interval type, value range:[20,100000000].
               
               > **NOTE:**  This module can only be purchased when vul_switch = 1. Only when the version_code value is level7 or level10. other versions do not need to be purchased separately.
        :param pulumi.Input[str] vul_switch: Vulnerability fix switch. Value:
               - 0: No.
               - 1: Yes.
               
               > **NOTE:**  When the value of version_code is level7 or level10, the purchase is allowed. Other versions do not need to be purchased separately.
        """
        if buy_number is not None:
            pulumi.set(__self__, "buy_number", buy_number)
        if container_image_scan is not None:
            warnings.warn("""Field 'container_image_scan' has been deprecated from provider version 1.212.0. Container Image security scan. Interval type, value interval:[0,200000].> The step size is 20, that is, only multiples of 20 can be filled in.""", DeprecationWarning)
            pulumi.log.warn("""container_image_scan is deprecated: Field 'container_image_scan' has been deprecated from provider version 1.212.0. Container Image security scan. Interval type, value interval:[0,200000].> The step size is 20, that is, only multiples of 20 can be filled in.""")
        if container_image_scan is not None:
            pulumi.set(__self__, "container_image_scan", container_image_scan)
        if container_image_scan_new is not None:
            pulumi.set(__self__, "container_image_scan_new", container_image_scan_new)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if honeypot is not None:
            pulumi.set(__self__, "honeypot", honeypot)
        if honeypot_switch is not None:
            pulumi.set(__self__, "honeypot_switch", honeypot_switch)
        if modify_type is not None:
            pulumi.set(__self__, "modify_type", modify_type)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if period is not None:
            pulumi.set(__self__, "period", period)
        if rasp_count is not None:
            pulumi.set(__self__, "rasp_count", rasp_count)
        if renew_period is not None:
            pulumi.set(__self__, "renew_period", renew_period)
        if renewal_period_unit is not None:
            pulumi.set(__self__, "renewal_period_unit", renewal_period_unit)
        if renewal_status is not None:
            pulumi.set(__self__, "renewal_status", renewal_status)
        if sas_anti_ransomware is not None:
            pulumi.set(__self__, "sas_anti_ransomware", sas_anti_ransomware)
        if sas_cspm is not None:
            pulumi.set(__self__, "sas_cspm", sas_cspm)
        if sas_cspm_switch is not None:
            pulumi.set(__self__, "sas_cspm_switch", sas_cspm_switch)
        if sas_sc is not None:
            pulumi.set(__self__, "sas_sc", sas_sc)
        if sas_sdk is not None:
            pulumi.set(__self__, "sas_sdk", sas_sdk)
        if sas_sdk_switch is not None:
            pulumi.set(__self__, "sas_sdk_switch", sas_sdk_switch)
        if sas_sls_storage is not None:
            pulumi.set(__self__, "sas_sls_storage", sas_sls_storage)
        if sas_webguard_boolean is not None:
            pulumi.set(__self__, "sas_webguard_boolean", sas_webguard_boolean)
        if sas_webguard_order_num is not None:
            pulumi.set(__self__, "sas_webguard_order_num", sas_webguard_order_num)
        if status is not None:
            pulumi.set(__self__, "status", status)
        if threat_analysis is not None:
            pulumi.set(__self__, "threat_analysis", threat_analysis)
        if threat_analysis_flow is not None:
            pulumi.set(__self__, "threat_analysis_flow", threat_analysis_flow)
        if threat_analysis_sls_storage is not None:
            pulumi.set(__self__, "threat_analysis_sls_storage", threat_analysis_sls_storage)
        if threat_analysis_switch is not None:
            pulumi.set(__self__, "threat_analysis_switch", threat_analysis_switch)
        if threat_analysis_switch1 is not None:
            pulumi.set(__self__, "threat_analysis_switch1", threat_analysis_switch1)
        if v_core is not None:
            pulumi.set(__self__, "v_core", v_core)
        if version_code is not None:
            pulumi.set(__self__, "version_code", version_code)
        if vul_count is not None:
            pulumi.set(__self__, "vul_count", vul_count)
        if vul_switch is not None:
            pulumi.set(__self__, "vul_switch", vul_switch)

    @property
    @pulumi.getter(name="buyNumber")
    def buy_number(self) -> Optional[pulumi.Input[str]]:
        """
        Number of servers.
        """
        return pulumi.get(self, "buy_number")

    @buy_number.setter
    def buy_number(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "buy_number", value)

    @property
    @pulumi.getter(name="containerImageScan")
    @_utilities.deprecated("""Field 'container_image_scan' has been deprecated from provider version 1.212.0. Container Image security scan. Interval type, value interval:[0,200000].> The step size is 20, that is, only multiples of 20 can be filled in.""")
    def container_image_scan(self) -> Optional[pulumi.Input[str]]:
        """
        Container Image security scan. Interval type, value interval:[0,200000].

        > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        """
        return pulumi.get(self, "container_image_scan")

    @container_image_scan.setter
    def container_image_scan(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "container_image_scan", value)

    @property
    @pulumi.getter(name="containerImageScanNew")
    def container_image_scan_new(self) -> Optional[pulumi.Input[str]]:
        """
        Container Image security scan. Interval type, value interval:[0,200000].

        > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        """
        return pulumi.get(self, "container_image_scan_new")

    @container_image_scan_new.setter
    def container_image_scan_new(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "container_image_scan_new", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def honeypot(self) -> Optional[pulumi.Input[str]]:
        """
        Number of cloud honeypot licenses. Interval type, value interval:[20,500].

        > **NOTE:**  This module can only be purchased when honeypot_switch = 1, starting with 20.
        """
        return pulumi.get(self, "honeypot")

    @honeypot.setter
    def honeypot(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "honeypot", value)

    @property
    @pulumi.getter(name="honeypotSwitch")
    def honeypot_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Cloud honeypot. Value:
        - 1: Yes.
        - 2: No.
        """
        return pulumi.get(self, "honeypot_switch")

    @honeypot_switch.setter
    def honeypot_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "honeypot_switch", value)

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> Optional[pulumi.Input[str]]:
        """
        Change configuration type, value
        - Upgrade: Upgrade.
        - Downgrade: Downgrade.
        """
        return pulumi.get(self, "modify_type")

    @modify_type.setter
    def modify_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "modify_type", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The payment type of the resource
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def period(self) -> Optional[pulumi.Input[int]]:
        """
        Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.

        > **NOTE:**  must be set when creating a prepaid instance.
        """
        return pulumi.get(self, "period")

    @period.setter
    def period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "period", value)

    @property
    @pulumi.getter(name="raspCount")
    def rasp_count(self) -> Optional[pulumi.Input[str]]:
        """
        Number of application protection licenses. Interval type, value interval:[1,100000000].
        """
        return pulumi.get(self, "rasp_count")

    @rasp_count.setter
    def rasp_count(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "rasp_count", value)

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> Optional[pulumi.Input[int]]:
        """
        Automatic renewal cycle, in months.

        > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        """
        return pulumi.get(self, "renew_period")

    @renew_period.setter
    def renew_period(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "renew_period", value)

    @property
    @pulumi.getter(name="renewalPeriodUnit")
    def renewal_period_unit(self) -> Optional[pulumi.Input[str]]:
        """
        Automatic renewal period unit, value:
        - M: month.
        - Y: years.

        > **NOTE:**  Must be set when RenewalStatus = AutoRenewal.
        """
        return pulumi.get(self, "renewal_period_unit")

    @renewal_period_unit.setter
    def renewal_period_unit(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_period_unit", value)

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> Optional[pulumi.Input[str]]:
        """
        Automatic renewal status, value:
        - AutoRenewal: automatic renewal.
        - ManualRenewal: manual renewal.

        Default ManualRenewal.
        """
        return pulumi.get(self, "renewal_status")

    @renewal_status.setter
    def renewal_status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "renewal_status", value)

    @property
    @pulumi.getter(name="sasAntiRansomware")
    def sas_anti_ransomware(self) -> Optional[pulumi.Input[str]]:
        """
        Anti-ransomware capacity. Unit: GB. Interval type, value interval:[0,9999999999].

        > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "sas_anti_ransomware")

    @sas_anti_ransomware.setter
    def sas_anti_ransomware(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_anti_ransomware", value)

    @property
    @pulumi.getter(name="sasCspm")
    def sas_cspm(self) -> Optional[pulumi.Input[str]]:
        """
        Cloud platform configuration check scan times, interval type, value range:[15000,9999999999].

        > **NOTE:**  You must have sas_cspm_switch = 1 to purchase this module. The step size is 55000, that is, only multiples of 55000 can be filled in.
        """
        return pulumi.get(self, "sas_cspm")

    @sas_cspm.setter
    def sas_cspm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_cspm", value)

    @property
    @pulumi.getter(name="sasCspmSwitch")
    def sas_cspm_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Cloud platform configuration check switch. Value:
        - 0: No.
        - 1: Yes.
        """
        return pulumi.get(self, "sas_cspm_switch")

    @sas_cspm_switch.setter
    def sas_cspm_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_cspm_switch", value)

    @property
    @pulumi.getter(name="sasSc")
    def sas_sc(self) -> Optional[pulumi.Input[bool]]:
        """
        Security screen. Value:
        - true: Yes.
        - false: No.
        """
        return pulumi.get(self, "sas_sc")

    @sas_sc.setter
    def sas_sc(self, value: Optional[pulumi.Input[bool]]):
        pulumi.set(self, "sas_sc", value)

    @property
    @pulumi.getter(name="sasSdk")
    def sas_sdk(self) -> Optional[pulumi.Input[str]]:
        """
        Number of malicious file detections. Unit: 10,000 times. Interval type, value interval:[10,9999999999].

        > **NOTE:**  This module can only be purchased when sas_sdk_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "sas_sdk")

    @sas_sdk.setter
    def sas_sdk(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_sdk", value)

    @property
    @pulumi.getter(name="sasSdkSwitch")
    def sas_sdk_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Malicious file detection SDK.
        """
        return pulumi.get(self, "sas_sdk_switch")

    @sas_sdk_switch.setter
    def sas_sdk_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_sdk_switch", value)

    @property
    @pulumi.getter(name="sasSlsStorage")
    def sas_sls_storage(self) -> Optional[pulumi.Input[str]]:
        """
        Log analysis storage capacity. Unit: GB. Interval type, value interval:[0,600000].

        > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "sas_sls_storage")

    @sas_sls_storage.setter
    def sas_sls_storage(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_sls_storage", value)

    @property
    @pulumi.getter(name="sasWebguardBoolean")
    def sas_webguard_boolean(self) -> Optional[pulumi.Input[str]]:
        """
        Web tamper-proof switch. Value:
        - 0: No.
        - 1: Yes.
        """
        return pulumi.get(self, "sas_webguard_boolean")

    @sas_webguard_boolean.setter
    def sas_webguard_boolean(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_webguard_boolean", value)

    @property
    @pulumi.getter(name="sasWebguardOrderNum")
    def sas_webguard_order_num(self) -> Optional[pulumi.Input[str]]:
        """
        Tamper-proof authorization number. Value:
        - 0: No
        - 1: Yes.
        """
        return pulumi.get(self, "sas_webguard_order_num")

    @sas_webguard_order_num.setter
    def sas_webguard_order_num(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sas_webguard_order_num", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)

    @property
    @pulumi.getter(name="threatAnalysis")
    def threat_analysis(self) -> Optional[pulumi.Input[str]]:
        """
        Threat Analysis log storage capacity. Interval type, value interval:[0,9999999999].

        > **NOTE:**  This module can only be purchased when Threat_analysis_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "threat_analysis")

    @threat_analysis.setter
    def threat_analysis(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "threat_analysis", value)

    @property
    @pulumi.getter(name="threatAnalysisFlow")
    def threat_analysis_flow(self) -> Optional[pulumi.Input[str]]:
        """
        Threat analysis and response log access traffic. After ThreatAnalysisSwitch1 is selected, it must be selected. Interval type, value interval:[0,9999999999].

        > **NOTE:**  Step size is 1.
        """
        return pulumi.get(self, "threat_analysis_flow")

    @threat_analysis_flow.setter
    def threat_analysis_flow(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "threat_analysis_flow", value)

    @property
    @pulumi.getter(name="threatAnalysisSlsStorage")
    def threat_analysis_sls_storage(self) -> Optional[pulumi.Input[str]]:
        """
        Threat analysis and response log storage capacity. Interval type, value interval:[0,9999999999].

        > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "threat_analysis_sls_storage")

    @threat_analysis_sls_storage.setter
    def threat_analysis_sls_storage(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "threat_analysis_sls_storage", value)

    @property
    @pulumi.getter(name="threatAnalysisSwitch")
    def threat_analysis_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Threat analysis. Value:
        - 0: No.
        - 1: Yes.
        """
        return pulumi.get(self, "threat_analysis_switch")

    @threat_analysis_switch.setter
    def threat_analysis_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "threat_analysis_switch", value)

    @property
    @pulumi.getter(name="threatAnalysisSwitch1")
    def threat_analysis_switch1(self) -> Optional[pulumi.Input[str]]:
        """
        Threat analysis and response switch (new), values:
        - 0: No
        - 1: Yes
        """
        return pulumi.get(self, "threat_analysis_switch1")

    @threat_analysis_switch1.setter
    def threat_analysis_switch1(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "threat_analysis_switch1", value)

    @property
    @pulumi.getter(name="vCore")
    def v_core(self) -> Optional[pulumi.Input[str]]:
        """
        Number of cores.
        """
        return pulumi.get(self, "v_core")

    @v_core.setter
    def v_core(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "v_core", value)

    @property
    @pulumi.getter(name="versionCode")
    def version_code(self) -> Optional[pulumi.Input[str]]:
        """
        Select the security center version. Value:
        - level7: Antivirus Edition.
        - level3: Premium version.
        - level2: Enterprise Edition.
        - level8: Ultimate.
        - level10: Purchase value-added services only.
        """
        return pulumi.get(self, "version_code")

    @version_code.setter
    def version_code(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "version_code", value)

    @property
    @pulumi.getter(name="vulCount")
    def vul_count(self) -> Optional[pulumi.Input[str]]:
        """
        Vulnerability repair times, interval type, value range:[20,100000000].

        > **NOTE:**  This module can only be purchased when vul_switch = 1. Only when the version_code value is level7 or level10. other versions do not need to be purchased separately.
        """
        return pulumi.get(self, "vul_count")

    @vul_count.setter
    def vul_count(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vul_count", value)

    @property
    @pulumi.getter(name="vulSwitch")
    def vul_switch(self) -> Optional[pulumi.Input[str]]:
        """
        Vulnerability fix switch. Value:
        - 0: No.
        - 1: Yes.

        > **NOTE:**  When the value of version_code is level7 or level10, the purchase is allowed. Other versions do not need to be purchased separately.
        """
        return pulumi.get(self, "vul_switch")

    @vul_switch.setter
    def vul_switch(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "vul_switch", value)


class Instance(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 buy_number: Optional[pulumi.Input[str]] = None,
                 container_image_scan: Optional[pulumi.Input[str]] = None,
                 container_image_scan_new: Optional[pulumi.Input[str]] = None,
                 honeypot: Optional[pulumi.Input[str]] = None,
                 honeypot_switch: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 rasp_count: Optional[pulumi.Input[str]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_period_unit: Optional[pulumi.Input[str]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 sas_anti_ransomware: Optional[pulumi.Input[str]] = None,
                 sas_cspm: Optional[pulumi.Input[str]] = None,
                 sas_cspm_switch: Optional[pulumi.Input[str]] = None,
                 sas_sc: Optional[pulumi.Input[bool]] = None,
                 sas_sdk: Optional[pulumi.Input[str]] = None,
                 sas_sdk_switch: Optional[pulumi.Input[str]] = None,
                 sas_sls_storage: Optional[pulumi.Input[str]] = None,
                 sas_webguard_boolean: Optional[pulumi.Input[str]] = None,
                 sas_webguard_order_num: Optional[pulumi.Input[str]] = None,
                 threat_analysis: Optional[pulumi.Input[str]] = None,
                 threat_analysis_flow: Optional[pulumi.Input[str]] = None,
                 threat_analysis_sls_storage: Optional[pulumi.Input[str]] = None,
                 threat_analysis_switch: Optional[pulumi.Input[str]] = None,
                 threat_analysis_switch1: Optional[pulumi.Input[str]] = None,
                 v_core: Optional[pulumi.Input[str]] = None,
                 version_code: Optional[pulumi.Input[str]] = None,
                 vul_count: Optional[pulumi.Input[str]] = None,
                 vul_switch: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        ## Import

        Threat Detection Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:threatdetection/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] buy_number: Number of servers.
        :param pulumi.Input[str] container_image_scan: Container Image security scan. Interval type, value interval:[0,200000].
               
               > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        :param pulumi.Input[str] container_image_scan_new: Container Image security scan. Interval type, value interval:[0,200000].
               
               > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        :param pulumi.Input[str] honeypot: Number of cloud honeypot licenses. Interval type, value interval:[20,500].
               
               > **NOTE:**  This module can only be purchased when honeypot_switch = 1, starting with 20.
        :param pulumi.Input[str] honeypot_switch: Cloud honeypot. Value:
               - 1: Yes.
               - 2: No.
        :param pulumi.Input[str] modify_type: Change configuration type, value
               - Upgrade: Upgrade.
               - Downgrade: Downgrade.
        :param pulumi.Input[str] payment_type: The payment type of the resource
        :param pulumi.Input[int] period: Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.
               
               > **NOTE:**  must be set when creating a prepaid instance.
        :param pulumi.Input[str] rasp_count: Number of application protection licenses. Interval type, value interval:[1,100000000].
        :param pulumi.Input[int] renew_period: Automatic renewal cycle, in months.
               
               > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        :param pulumi.Input[str] renewal_period_unit: Automatic renewal period unit, value:
               - M: month.
               - Y: years.
               
               > **NOTE:**  Must be set when RenewalStatus = AutoRenewal.
        :param pulumi.Input[str] renewal_status: Automatic renewal status, value:
               - AutoRenewal: automatic renewal.
               - ManualRenewal: manual renewal.
               
               Default ManualRenewal.
        :param pulumi.Input[str] sas_anti_ransomware: Anti-ransomware capacity. Unit: GB. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_cspm: Cloud platform configuration check scan times, interval type, value range:[15000,9999999999].
               
               > **NOTE:**  You must have sas_cspm_switch = 1 to purchase this module. The step size is 55000, that is, only multiples of 55000 can be filled in.
        :param pulumi.Input[str] sas_cspm_switch: Cloud platform configuration check switch. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[bool] sas_sc: Security screen. Value:
               - true: Yes.
               - false: No.
        :param pulumi.Input[str] sas_sdk: Number of malicious file detections. Unit: 10,000 times. Interval type, value interval:[10,9999999999].
               
               > **NOTE:**  This module can only be purchased when sas_sdk_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_sdk_switch: Malicious file detection SDK.
        :param pulumi.Input[str] sas_sls_storage: Log analysis storage capacity. Unit: GB. Interval type, value interval:[0,600000].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_webguard_boolean: Web tamper-proof switch. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[str] sas_webguard_order_num: Tamper-proof authorization number. Value:
               - 0: No
               - 1: Yes.
        :param pulumi.Input[str] threat_analysis: Threat Analysis log storage capacity. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  This module can only be purchased when Threat_analysis_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] threat_analysis_flow: Threat analysis and response log access traffic. After ThreatAnalysisSwitch1 is selected, it must be selected. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  Step size is 1.
        :param pulumi.Input[str] threat_analysis_sls_storage: Threat analysis and response log storage capacity. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] threat_analysis_switch: Threat analysis. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[str] threat_analysis_switch1: Threat analysis and response switch (new), values:
               - 0: No
               - 1: Yes
        :param pulumi.Input[str] v_core: Number of cores.
        :param pulumi.Input[str] version_code: Select the security center version. Value:
               - level7: Antivirus Edition.
               - level3: Premium version.
               - level2: Enterprise Edition.
               - level8: Ultimate.
               - level10: Purchase value-added services only.
        :param pulumi.Input[str] vul_count: Vulnerability repair times, interval type, value range:[20,100000000].
               
               > **NOTE:**  This module can only be purchased when vul_switch = 1. Only when the version_code value is level7 or level10. other versions do not need to be purchased separately.
        :param pulumi.Input[str] vul_switch: Vulnerability fix switch. Value:
               - 0: No.
               - 1: Yes.
               
               > **NOTE:**  When the value of version_code is level7 or level10, the purchase is allowed. Other versions do not need to be purchased separately.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: InstanceArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        ## Import

        Threat Detection Instance can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:threatdetection/instance:Instance example <id>
        ```

        :param str resource_name: The name of the resource.
        :param InstanceArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(InstanceArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 buy_number: Optional[pulumi.Input[str]] = None,
                 container_image_scan: Optional[pulumi.Input[str]] = None,
                 container_image_scan_new: Optional[pulumi.Input[str]] = None,
                 honeypot: Optional[pulumi.Input[str]] = None,
                 honeypot_switch: Optional[pulumi.Input[str]] = None,
                 modify_type: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 period: Optional[pulumi.Input[int]] = None,
                 rasp_count: Optional[pulumi.Input[str]] = None,
                 renew_period: Optional[pulumi.Input[int]] = None,
                 renewal_period_unit: Optional[pulumi.Input[str]] = None,
                 renewal_status: Optional[pulumi.Input[str]] = None,
                 sas_anti_ransomware: Optional[pulumi.Input[str]] = None,
                 sas_cspm: Optional[pulumi.Input[str]] = None,
                 sas_cspm_switch: Optional[pulumi.Input[str]] = None,
                 sas_sc: Optional[pulumi.Input[bool]] = None,
                 sas_sdk: Optional[pulumi.Input[str]] = None,
                 sas_sdk_switch: Optional[pulumi.Input[str]] = None,
                 sas_sls_storage: Optional[pulumi.Input[str]] = None,
                 sas_webguard_boolean: Optional[pulumi.Input[str]] = None,
                 sas_webguard_order_num: Optional[pulumi.Input[str]] = None,
                 threat_analysis: Optional[pulumi.Input[str]] = None,
                 threat_analysis_flow: Optional[pulumi.Input[str]] = None,
                 threat_analysis_sls_storage: Optional[pulumi.Input[str]] = None,
                 threat_analysis_switch: Optional[pulumi.Input[str]] = None,
                 threat_analysis_switch1: Optional[pulumi.Input[str]] = None,
                 v_core: Optional[pulumi.Input[str]] = None,
                 version_code: Optional[pulumi.Input[str]] = None,
                 vul_count: Optional[pulumi.Input[str]] = None,
                 vul_switch: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = InstanceArgs.__new__(InstanceArgs)

            __props__.__dict__["buy_number"] = buy_number
            __props__.__dict__["container_image_scan"] = container_image_scan
            __props__.__dict__["container_image_scan_new"] = container_image_scan_new
            __props__.__dict__["honeypot"] = honeypot
            __props__.__dict__["honeypot_switch"] = honeypot_switch
            __props__.__dict__["modify_type"] = modify_type
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["period"] = period
            __props__.__dict__["rasp_count"] = rasp_count
            __props__.__dict__["renew_period"] = renew_period
            __props__.__dict__["renewal_period_unit"] = renewal_period_unit
            __props__.__dict__["renewal_status"] = renewal_status
            __props__.__dict__["sas_anti_ransomware"] = sas_anti_ransomware
            __props__.__dict__["sas_cspm"] = sas_cspm
            __props__.__dict__["sas_cspm_switch"] = sas_cspm_switch
            __props__.__dict__["sas_sc"] = sas_sc
            __props__.__dict__["sas_sdk"] = sas_sdk
            __props__.__dict__["sas_sdk_switch"] = sas_sdk_switch
            __props__.__dict__["sas_sls_storage"] = sas_sls_storage
            __props__.__dict__["sas_webguard_boolean"] = sas_webguard_boolean
            __props__.__dict__["sas_webguard_order_num"] = sas_webguard_order_num
            __props__.__dict__["threat_analysis"] = threat_analysis
            __props__.__dict__["threat_analysis_flow"] = threat_analysis_flow
            __props__.__dict__["threat_analysis_sls_storage"] = threat_analysis_sls_storage
            __props__.__dict__["threat_analysis_switch"] = threat_analysis_switch
            __props__.__dict__["threat_analysis_switch1"] = threat_analysis_switch1
            __props__.__dict__["v_core"] = v_core
            if version_code is None and not opts.urn:
                raise TypeError("Missing required property 'version_code'")
            __props__.__dict__["version_code"] = version_code
            __props__.__dict__["vul_count"] = vul_count
            __props__.__dict__["vul_switch"] = vul_switch
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(Instance, __self__).__init__(
            'alicloud:threatdetection/instance:Instance',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            buy_number: Optional[pulumi.Input[str]] = None,
            container_image_scan: Optional[pulumi.Input[str]] = None,
            container_image_scan_new: Optional[pulumi.Input[str]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            honeypot: Optional[pulumi.Input[str]] = None,
            honeypot_switch: Optional[pulumi.Input[str]] = None,
            modify_type: Optional[pulumi.Input[str]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            period: Optional[pulumi.Input[int]] = None,
            rasp_count: Optional[pulumi.Input[str]] = None,
            renew_period: Optional[pulumi.Input[int]] = None,
            renewal_period_unit: Optional[pulumi.Input[str]] = None,
            renewal_status: Optional[pulumi.Input[str]] = None,
            sas_anti_ransomware: Optional[pulumi.Input[str]] = None,
            sas_cspm: Optional[pulumi.Input[str]] = None,
            sas_cspm_switch: Optional[pulumi.Input[str]] = None,
            sas_sc: Optional[pulumi.Input[bool]] = None,
            sas_sdk: Optional[pulumi.Input[str]] = None,
            sas_sdk_switch: Optional[pulumi.Input[str]] = None,
            sas_sls_storage: Optional[pulumi.Input[str]] = None,
            sas_webguard_boolean: Optional[pulumi.Input[str]] = None,
            sas_webguard_order_num: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None,
            threat_analysis: Optional[pulumi.Input[str]] = None,
            threat_analysis_flow: Optional[pulumi.Input[str]] = None,
            threat_analysis_sls_storage: Optional[pulumi.Input[str]] = None,
            threat_analysis_switch: Optional[pulumi.Input[str]] = None,
            threat_analysis_switch1: Optional[pulumi.Input[str]] = None,
            v_core: Optional[pulumi.Input[str]] = None,
            version_code: Optional[pulumi.Input[str]] = None,
            vul_count: Optional[pulumi.Input[str]] = None,
            vul_switch: Optional[pulumi.Input[str]] = None) -> 'Instance':
        """
        Get an existing Instance resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] buy_number: Number of servers.
        :param pulumi.Input[str] container_image_scan: Container Image security scan. Interval type, value interval:[0,200000].
               
               > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        :param pulumi.Input[str] container_image_scan_new: Container Image security scan. Interval type, value interval:[0,200000].
               
               > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        :param pulumi.Input[str] create_time: The creation time of the resource
        :param pulumi.Input[str] honeypot: Number of cloud honeypot licenses. Interval type, value interval:[20,500].
               
               > **NOTE:**  This module can only be purchased when honeypot_switch = 1, starting with 20.
        :param pulumi.Input[str] honeypot_switch: Cloud honeypot. Value:
               - 1: Yes.
               - 2: No.
        :param pulumi.Input[str] modify_type: Change configuration type, value
               - Upgrade: Upgrade.
               - Downgrade: Downgrade.
        :param pulumi.Input[str] payment_type: The payment type of the resource
        :param pulumi.Input[int] period: Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.
               
               > **NOTE:**  must be set when creating a prepaid instance.
        :param pulumi.Input[str] rasp_count: Number of application protection licenses. Interval type, value interval:[1,100000000].
        :param pulumi.Input[int] renew_period: Automatic renewal cycle, in months.
               
               > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        :param pulumi.Input[str] renewal_period_unit: Automatic renewal period unit, value:
               - M: month.
               - Y: years.
               
               > **NOTE:**  Must be set when RenewalStatus = AutoRenewal.
        :param pulumi.Input[str] renewal_status: Automatic renewal status, value:
               - AutoRenewal: automatic renewal.
               - ManualRenewal: manual renewal.
               
               Default ManualRenewal.
        :param pulumi.Input[str] sas_anti_ransomware: Anti-ransomware capacity. Unit: GB. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_cspm: Cloud platform configuration check scan times, interval type, value range:[15000,9999999999].
               
               > **NOTE:**  You must have sas_cspm_switch = 1 to purchase this module. The step size is 55000, that is, only multiples of 55000 can be filled in.
        :param pulumi.Input[str] sas_cspm_switch: Cloud platform configuration check switch. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[bool] sas_sc: Security screen. Value:
               - true: Yes.
               - false: No.
        :param pulumi.Input[str] sas_sdk: Number of malicious file detections. Unit: 10,000 times. Interval type, value interval:[10,9999999999].
               
               > **NOTE:**  This module can only be purchased when sas_sdk_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_sdk_switch: Malicious file detection SDK.
        :param pulumi.Input[str] sas_sls_storage: Log analysis storage capacity. Unit: GB. Interval type, value interval:[0,600000].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] sas_webguard_boolean: Web tamper-proof switch. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[str] sas_webguard_order_num: Tamper-proof authorization number. Value:
               - 0: No
               - 1: Yes.
        :param pulumi.Input[str] status: The status of the resource
        :param pulumi.Input[str] threat_analysis: Threat Analysis log storage capacity. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  This module can only be purchased when Threat_analysis_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] threat_analysis_flow: Threat analysis and response log access traffic. After ThreatAnalysisSwitch1 is selected, it must be selected. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  Step size is 1.
        :param pulumi.Input[str] threat_analysis_sls_storage: Threat analysis and response log storage capacity. Interval type, value interval:[0,9999999999].
               
               > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        :param pulumi.Input[str] threat_analysis_switch: Threat analysis. Value:
               - 0: No.
               - 1: Yes.
        :param pulumi.Input[str] threat_analysis_switch1: Threat analysis and response switch (new), values:
               - 0: No
               - 1: Yes
        :param pulumi.Input[str] v_core: Number of cores.
        :param pulumi.Input[str] version_code: Select the security center version. Value:
               - level7: Antivirus Edition.
               - level3: Premium version.
               - level2: Enterprise Edition.
               - level8: Ultimate.
               - level10: Purchase value-added services only.
        :param pulumi.Input[str] vul_count: Vulnerability repair times, interval type, value range:[20,100000000].
               
               > **NOTE:**  This module can only be purchased when vul_switch = 1. Only when the version_code value is level7 or level10. other versions do not need to be purchased separately.
        :param pulumi.Input[str] vul_switch: Vulnerability fix switch. Value:
               - 0: No.
               - 1: Yes.
               
               > **NOTE:**  When the value of version_code is level7 or level10, the purchase is allowed. Other versions do not need to be purchased separately.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _InstanceState.__new__(_InstanceState)

        __props__.__dict__["buy_number"] = buy_number
        __props__.__dict__["container_image_scan"] = container_image_scan
        __props__.__dict__["container_image_scan_new"] = container_image_scan_new
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["honeypot"] = honeypot
        __props__.__dict__["honeypot_switch"] = honeypot_switch
        __props__.__dict__["modify_type"] = modify_type
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["period"] = period
        __props__.__dict__["rasp_count"] = rasp_count
        __props__.__dict__["renew_period"] = renew_period
        __props__.__dict__["renewal_period_unit"] = renewal_period_unit
        __props__.__dict__["renewal_status"] = renewal_status
        __props__.__dict__["sas_anti_ransomware"] = sas_anti_ransomware
        __props__.__dict__["sas_cspm"] = sas_cspm
        __props__.__dict__["sas_cspm_switch"] = sas_cspm_switch
        __props__.__dict__["sas_sc"] = sas_sc
        __props__.__dict__["sas_sdk"] = sas_sdk
        __props__.__dict__["sas_sdk_switch"] = sas_sdk_switch
        __props__.__dict__["sas_sls_storage"] = sas_sls_storage
        __props__.__dict__["sas_webguard_boolean"] = sas_webguard_boolean
        __props__.__dict__["sas_webguard_order_num"] = sas_webguard_order_num
        __props__.__dict__["status"] = status
        __props__.__dict__["threat_analysis"] = threat_analysis
        __props__.__dict__["threat_analysis_flow"] = threat_analysis_flow
        __props__.__dict__["threat_analysis_sls_storage"] = threat_analysis_sls_storage
        __props__.__dict__["threat_analysis_switch"] = threat_analysis_switch
        __props__.__dict__["threat_analysis_switch1"] = threat_analysis_switch1
        __props__.__dict__["v_core"] = v_core
        __props__.__dict__["version_code"] = version_code
        __props__.__dict__["vul_count"] = vul_count
        __props__.__dict__["vul_switch"] = vul_switch
        return Instance(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter(name="buyNumber")
    def buy_number(self) -> pulumi.Output[Optional[str]]:
        """
        Number of servers.
        """
        return pulumi.get(self, "buy_number")

    @property
    @pulumi.getter(name="containerImageScan")
    @_utilities.deprecated("""Field 'container_image_scan' has been deprecated from provider version 1.212.0. Container Image security scan. Interval type, value interval:[0,200000].> The step size is 20, that is, only multiples of 20 can be filled in.""")
    def container_image_scan(self) -> pulumi.Output[Optional[str]]:
        """
        Container Image security scan. Interval type, value interval:[0,200000].

        > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        """
        return pulumi.get(self, "container_image_scan")

    @property
    @pulumi.getter(name="containerImageScanNew")
    def container_image_scan_new(self) -> pulumi.Output[Optional[str]]:
        """
        Container Image security scan. Interval type, value interval:[0,200000].

        > **NOTE:**  The step size is 20, that is, only multiples of 20 can be filled in.
        """
        return pulumi.get(self, "container_image_scan_new")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the resource
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def honeypot(self) -> pulumi.Output[Optional[str]]:
        """
        Number of cloud honeypot licenses. Interval type, value interval:[20,500].

        > **NOTE:**  This module can only be purchased when honeypot_switch = 1, starting with 20.
        """
        return pulumi.get(self, "honeypot")

    @property
    @pulumi.getter(name="honeypotSwitch")
    def honeypot_switch(self) -> pulumi.Output[str]:
        """
        Cloud honeypot. Value:
        - 1: Yes.
        - 2: No.
        """
        return pulumi.get(self, "honeypot_switch")

    @property
    @pulumi.getter(name="modifyType")
    def modify_type(self) -> pulumi.Output[Optional[str]]:
        """
        Change configuration type, value
        - Upgrade: Upgrade.
        - Downgrade: Downgrade.
        """
        return pulumi.get(self, "modify_type")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The payment type of the resource
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def period(self) -> pulumi.Output[Optional[int]]:
        """
        Prepaid cycle. The unit is Monthly, please enter an integer multiple of 12 for annual paid products.

        > **NOTE:**  must be set when creating a prepaid instance.
        """
        return pulumi.get(self, "period")

    @property
    @pulumi.getter(name="raspCount")
    def rasp_count(self) -> pulumi.Output[Optional[str]]:
        """
        Number of application protection licenses. Interval type, value interval:[1,100000000].
        """
        return pulumi.get(self, "rasp_count")

    @property
    @pulumi.getter(name="renewPeriod")
    def renew_period(self) -> pulumi.Output[int]:
        """
        Automatic renewal cycle, in months.

        > **NOTE:**  When `RenewalStatus` is set to `AutoRenewal`, it must be set.
        """
        return pulumi.get(self, "renew_period")

    @property
    @pulumi.getter(name="renewalPeriodUnit")
    def renewal_period_unit(self) -> pulumi.Output[str]:
        """
        Automatic renewal period unit, value:
        - M: month.
        - Y: years.

        > **NOTE:**  Must be set when RenewalStatus = AutoRenewal.
        """
        return pulumi.get(self, "renewal_period_unit")

    @property
    @pulumi.getter(name="renewalStatus")
    def renewal_status(self) -> pulumi.Output[Optional[str]]:
        """
        Automatic renewal status, value:
        - AutoRenewal: automatic renewal.
        - ManualRenewal: manual renewal.

        Default ManualRenewal.
        """
        return pulumi.get(self, "renewal_status")

    @property
    @pulumi.getter(name="sasAntiRansomware")
    def sas_anti_ransomware(self) -> pulumi.Output[Optional[str]]:
        """
        Anti-ransomware capacity. Unit: GB. Interval type, value interval:[0,9999999999].

        > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "sas_anti_ransomware")

    @property
    @pulumi.getter(name="sasCspm")
    def sas_cspm(self) -> pulumi.Output[Optional[str]]:
        """
        Cloud platform configuration check scan times, interval type, value range:[15000,9999999999].

        > **NOTE:**  You must have sas_cspm_switch = 1 to purchase this module. The step size is 55000, that is, only multiples of 55000 can be filled in.
        """
        return pulumi.get(self, "sas_cspm")

    @property
    @pulumi.getter(name="sasCspmSwitch")
    def sas_cspm_switch(self) -> pulumi.Output[str]:
        """
        Cloud platform configuration check switch. Value:
        - 0: No.
        - 1: Yes.
        """
        return pulumi.get(self, "sas_cspm_switch")

    @property
    @pulumi.getter(name="sasSc")
    def sas_sc(self) -> pulumi.Output[Optional[bool]]:
        """
        Security screen. Value:
        - true: Yes.
        - false: No.
        """
        return pulumi.get(self, "sas_sc")

    @property
    @pulumi.getter(name="sasSdk")
    def sas_sdk(self) -> pulumi.Output[Optional[str]]:
        """
        Number of malicious file detections. Unit: 10,000 times. Interval type, value interval:[10,9999999999].

        > **NOTE:**  This module can only be purchased when sas_sdk_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "sas_sdk")

    @property
    @pulumi.getter(name="sasSdkSwitch")
    def sas_sdk_switch(self) -> pulumi.Output[str]:
        """
        Malicious file detection SDK.
        """
        return pulumi.get(self, "sas_sdk_switch")

    @property
    @pulumi.getter(name="sasSlsStorage")
    def sas_sls_storage(self) -> pulumi.Output[Optional[str]]:
        """
        Log analysis storage capacity. Unit: GB. Interval type, value interval:[0,600000].

        > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "sas_sls_storage")

    @property
    @pulumi.getter(name="sasWebguardBoolean")
    def sas_webguard_boolean(self) -> pulumi.Output[str]:
        """
        Web tamper-proof switch. Value:
        - 0: No.
        - 1: Yes.
        """
        return pulumi.get(self, "sas_webguard_boolean")

    @property
    @pulumi.getter(name="sasWebguardOrderNum")
    def sas_webguard_order_num(self) -> pulumi.Output[Optional[str]]:
        """
        Tamper-proof authorization number. Value:
        - 0: No
        - 1: Yes.
        """
        return pulumi.get(self, "sas_webguard_order_num")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the resource
        """
        return pulumi.get(self, "status")

    @property
    @pulumi.getter(name="threatAnalysis")
    def threat_analysis(self) -> pulumi.Output[Optional[str]]:
        """
        Threat Analysis log storage capacity. Interval type, value interval:[0,9999999999].

        > **NOTE:**  This module can only be purchased when Threat_analysis_switch = 1. The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "threat_analysis")

    @property
    @pulumi.getter(name="threatAnalysisFlow")
    def threat_analysis_flow(self) -> pulumi.Output[Optional[str]]:
        """
        Threat analysis and response log access traffic. After ThreatAnalysisSwitch1 is selected, it must be selected. Interval type, value interval:[0,9999999999].

        > **NOTE:**  Step size is 1.
        """
        return pulumi.get(self, "threat_analysis_flow")

    @property
    @pulumi.getter(name="threatAnalysisSlsStorage")
    def threat_analysis_sls_storage(self) -> pulumi.Output[Optional[str]]:
        """
        Threat analysis and response log storage capacity. Interval type, value interval:[0,9999999999].

        > **NOTE:**  The step size is 10, that is, only multiples of 10 can be filled in.
        """
        return pulumi.get(self, "threat_analysis_sls_storage")

    @property
    @pulumi.getter(name="threatAnalysisSwitch")
    def threat_analysis_switch(self) -> pulumi.Output[str]:
        """
        Threat analysis. Value:
        - 0: No.
        - 1: Yes.
        """
        return pulumi.get(self, "threat_analysis_switch")

    @property
    @pulumi.getter(name="threatAnalysisSwitch1")
    def threat_analysis_switch1(self) -> pulumi.Output[str]:
        """
        Threat analysis and response switch (new), values:
        - 0: No
        - 1: Yes
        """
        return pulumi.get(self, "threat_analysis_switch1")

    @property
    @pulumi.getter(name="vCore")
    def v_core(self) -> pulumi.Output[Optional[str]]:
        """
        Number of cores.
        """
        return pulumi.get(self, "v_core")

    @property
    @pulumi.getter(name="versionCode")
    def version_code(self) -> pulumi.Output[str]:
        """
        Select the security center version. Value:
        - level7: Antivirus Edition.
        - level3: Premium version.
        - level2: Enterprise Edition.
        - level8: Ultimate.
        - level10: Purchase value-added services only.
        """
        return pulumi.get(self, "version_code")

    @property
    @pulumi.getter(name="vulCount")
    def vul_count(self) -> pulumi.Output[Optional[str]]:
        """
        Vulnerability repair times, interval type, value range:[20,100000000].

        > **NOTE:**  This module can only be purchased when vul_switch = 1. Only when the version_code value is level7 or level10. other versions do not need to be purchased separately.
        """
        return pulumi.get(self, "vul_count")

    @property
    @pulumi.getter(name="vulSwitch")
    def vul_switch(self) -> pulumi.Output[str]:
        """
        Vulnerability fix switch. Value:
        - 0: No.
        - 1: Yes.

        > **NOTE:**  When the value of version_code is level7 or level10, the purchase is allowed. Other versions do not need to be purchased separately.
        """
        return pulumi.get(self, "vul_switch")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['BucketServerSideEncryptionArgs', 'BucketServerSideEncryption']

@pulumi.input_type
class BucketServerSideEncryptionArgs:
    def __init__(__self__, *,
                 bucket: pulumi.Input[str],
                 sse_algorithm: pulumi.Input[str],
                 kms_data_encryption: Optional[pulumi.Input[str]] = None,
                 kms_master_key_id: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a BucketServerSideEncryption resource.
        :param pulumi.Input[str] bucket: The name of the bucket.
        :param pulumi.Input[str] sse_algorithm: The server-side encryption method. Valid Values: KMS, AES256.
        :param pulumi.Input[str] kms_data_encryption: The algorithm used to encrypt objects. If this element is not specified, objects are encrypted by using AES256. This element is valid only when the value of SSEAlgorithm is set to KMS.
        :param pulumi.Input[str] kms_master_key_id: The CMK ID that must be specified when SSEAlgorithm is set to KMS and a specified CMK is used for encryption. In other cases, this element must be set to null.
        """
        pulumi.set(__self__, "bucket", bucket)
        pulumi.set(__self__, "sse_algorithm", sse_algorithm)
        if kms_data_encryption is not None:
            pulumi.set(__self__, "kms_data_encryption", kms_data_encryption)
        if kms_master_key_id is not None:
            pulumi.set(__self__, "kms_master_key_id", kms_master_key_id)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Input[str]:
        """
        The name of the bucket.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: pulumi.Input[str]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="sseAlgorithm")
    def sse_algorithm(self) -> pulumi.Input[str]:
        """
        The server-side encryption method. Valid Values: KMS, AES256.
        """
        return pulumi.get(self, "sse_algorithm")

    @sse_algorithm.setter
    def sse_algorithm(self, value: pulumi.Input[str]):
        pulumi.set(self, "sse_algorithm", value)

    @property
    @pulumi.getter(name="kmsDataEncryption")
    def kms_data_encryption(self) -> Optional[pulumi.Input[str]]:
        """
        The algorithm used to encrypt objects. If this element is not specified, objects are encrypted by using AES256. This element is valid only when the value of SSEAlgorithm is set to KMS.
        """
        return pulumi.get(self, "kms_data_encryption")

    @kms_data_encryption.setter
    def kms_data_encryption(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kms_data_encryption", value)

    @property
    @pulumi.getter(name="kmsMasterKeyId")
    def kms_master_key_id(self) -> Optional[pulumi.Input[str]]:
        """
        The CMK ID that must be specified when SSEAlgorithm is set to KMS and a specified CMK is used for encryption. In other cases, this element must be set to null.
        """
        return pulumi.get(self, "kms_master_key_id")

    @kms_master_key_id.setter
    def kms_master_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kms_master_key_id", value)


@pulumi.input_type
class _BucketServerSideEncryptionState:
    def __init__(__self__, *,
                 bucket: Optional[pulumi.Input[str]] = None,
                 kms_data_encryption: Optional[pulumi.Input[str]] = None,
                 kms_master_key_id: Optional[pulumi.Input[str]] = None,
                 sse_algorithm: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering BucketServerSideEncryption resources.
        :param pulumi.Input[str] bucket: The name of the bucket.
        :param pulumi.Input[str] kms_data_encryption: The algorithm used to encrypt objects. If this element is not specified, objects are encrypted by using AES256. This element is valid only when the value of SSEAlgorithm is set to KMS.
        :param pulumi.Input[str] kms_master_key_id: The CMK ID that must be specified when SSEAlgorithm is set to KMS and a specified CMK is used for encryption. In other cases, this element must be set to null.
        :param pulumi.Input[str] sse_algorithm: The server-side encryption method. Valid Values: KMS, AES256.
        """
        if bucket is not None:
            pulumi.set(__self__, "bucket", bucket)
        if kms_data_encryption is not None:
            pulumi.set(__self__, "kms_data_encryption", kms_data_encryption)
        if kms_master_key_id is not None:
            pulumi.set(__self__, "kms_master_key_id", kms_master_key_id)
        if sse_algorithm is not None:
            pulumi.set(__self__, "sse_algorithm", sse_algorithm)

    @property
    @pulumi.getter
    def bucket(self) -> Optional[pulumi.Input[str]]:
        """
        The name of the bucket.
        """
        return pulumi.get(self, "bucket")

    @bucket.setter
    def bucket(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "bucket", value)

    @property
    @pulumi.getter(name="kmsDataEncryption")
    def kms_data_encryption(self) -> Optional[pulumi.Input[str]]:
        """
        The algorithm used to encrypt objects. If this element is not specified, objects are encrypted by using AES256. This element is valid only when the value of SSEAlgorithm is set to KMS.
        """
        return pulumi.get(self, "kms_data_encryption")

    @kms_data_encryption.setter
    def kms_data_encryption(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kms_data_encryption", value)

    @property
    @pulumi.getter(name="kmsMasterKeyId")
    def kms_master_key_id(self) -> Optional[pulumi.Input[str]]:
        """
        The CMK ID that must be specified when SSEAlgorithm is set to KMS and a specified CMK is used for encryption. In other cases, this element must be set to null.
        """
        return pulumi.get(self, "kms_master_key_id")

    @kms_master_key_id.setter
    def kms_master_key_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "kms_master_key_id", value)

    @property
    @pulumi.getter(name="sseAlgorithm")
    def sse_algorithm(self) -> Optional[pulumi.Input[str]]:
        """
        The server-side encryption method. Valid Values: KMS, AES256.
        """
        return pulumi.get(self, "sse_algorithm")

    @sse_algorithm.setter
    def sse_algorithm(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "sse_algorithm", value)


class BucketServerSideEncryption(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 kms_data_encryption: Optional[pulumi.Input[str]] = None,
                 kms_master_key_id: Optional[pulumi.Input[str]] = None,
                 sse_algorithm: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a OSS Bucket Server Side Encryption resource. Server-side encryption rules of the bucket.

        For information about OSS Bucket Server Side Encryption and how to use it, see [What is Bucket Server Side Encryption](https://www.alibabacloud.com/help/en/oss/developer-reference/putbucketencryption).

        > **NOTE:** Available since v1.222.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        create_bucket = alicloud.oss.Bucket("CreateBucket",
            storage_class="Standard",
            bucket=f"{name}-{default['result']}")
        get_kms = alicloud.kms.Key("GetKMS",
            origin="Aliyun_KMS",
            protection_level="SOFTWARE",
            description=name,
            key_spec="Aliyun_AES_256",
            key_usage="ENCRYPT/DECRYPT",
            automatic_rotation="Disabled",
            pending_window_in_days=7)
        default_bucket_server_side_encryption = alicloud.oss.BucketServerSideEncryption("default",
            kms_data_encryption="SM4",
            kms_master_key_id=get_kms.id,
            bucket=create_bucket.bucket,
            sse_algorithm="KMS")
        ```

        ## Import

        OSS Bucket Server Side Encryption can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oss/bucketServerSideEncryption:BucketServerSideEncryption example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bucket: The name of the bucket.
        :param pulumi.Input[str] kms_data_encryption: The algorithm used to encrypt objects. If this element is not specified, objects are encrypted by using AES256. This element is valid only when the value of SSEAlgorithm is set to KMS.
        :param pulumi.Input[str] kms_master_key_id: The CMK ID that must be specified when SSEAlgorithm is set to KMS and a specified CMK is used for encryption. In other cases, this element must be set to null.
        :param pulumi.Input[str] sse_algorithm: The server-side encryption method. Valid Values: KMS, AES256.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: BucketServerSideEncryptionArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a OSS Bucket Server Side Encryption resource. Server-side encryption rules of the bucket.

        For information about OSS Bucket Server Side Encryption and how to use it, see [What is Bucket Server Side Encryption](https://www.alibabacloud.com/help/en/oss/developer-reference/putbucketencryption).

        > **NOTE:** Available since v1.222.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud
        import pulumi_random as random

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = random.index.Integer("default",
            min=10000,
            max=99999)
        create_bucket = alicloud.oss.Bucket("CreateBucket",
            storage_class="Standard",
            bucket=f"{name}-{default['result']}")
        get_kms = alicloud.kms.Key("GetKMS",
            origin="Aliyun_KMS",
            protection_level="SOFTWARE",
            description=name,
            key_spec="Aliyun_AES_256",
            key_usage="ENCRYPT/DECRYPT",
            automatic_rotation="Disabled",
            pending_window_in_days=7)
        default_bucket_server_side_encryption = alicloud.oss.BucketServerSideEncryption("default",
            kms_data_encryption="SM4",
            kms_master_key_id=get_kms.id,
            bucket=create_bucket.bucket,
            sse_algorithm="KMS")
        ```

        ## Import

        OSS Bucket Server Side Encryption can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:oss/bucketServerSideEncryption:BucketServerSideEncryption example <id>
        ```

        :param str resource_name: The name of the resource.
        :param BucketServerSideEncryptionArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(BucketServerSideEncryptionArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bucket: Optional[pulumi.Input[str]] = None,
                 kms_data_encryption: Optional[pulumi.Input[str]] = None,
                 kms_master_key_id: Optional[pulumi.Input[str]] = None,
                 sse_algorithm: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = BucketServerSideEncryptionArgs.__new__(BucketServerSideEncryptionArgs)

            if bucket is None and not opts.urn:
                raise TypeError("Missing required property 'bucket'")
            __props__.__dict__["bucket"] = bucket
            __props__.__dict__["kms_data_encryption"] = kms_data_encryption
            __props__.__dict__["kms_master_key_id"] = kms_master_key_id
            if sse_algorithm is None and not opts.urn:
                raise TypeError("Missing required property 'sse_algorithm'")
            __props__.__dict__["sse_algorithm"] = sse_algorithm
        super(BucketServerSideEncryption, __self__).__init__(
            'alicloud:oss/bucketServerSideEncryption:BucketServerSideEncryption',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bucket: Optional[pulumi.Input[str]] = None,
            kms_data_encryption: Optional[pulumi.Input[str]] = None,
            kms_master_key_id: Optional[pulumi.Input[str]] = None,
            sse_algorithm: Optional[pulumi.Input[str]] = None) -> 'BucketServerSideEncryption':
        """
        Get an existing BucketServerSideEncryption resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[str] bucket: The name of the bucket.
        :param pulumi.Input[str] kms_data_encryption: The algorithm used to encrypt objects. If this element is not specified, objects are encrypted by using AES256. This element is valid only when the value of SSEAlgorithm is set to KMS.
        :param pulumi.Input[str] kms_master_key_id: The CMK ID that must be specified when SSEAlgorithm is set to KMS and a specified CMK is used for encryption. In other cases, this element must be set to null.
        :param pulumi.Input[str] sse_algorithm: The server-side encryption method. Valid Values: KMS, AES256.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _BucketServerSideEncryptionState.__new__(_BucketServerSideEncryptionState)

        __props__.__dict__["bucket"] = bucket
        __props__.__dict__["kms_data_encryption"] = kms_data_encryption
        __props__.__dict__["kms_master_key_id"] = kms_master_key_id
        __props__.__dict__["sse_algorithm"] = sse_algorithm
        return BucketServerSideEncryption(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def bucket(self) -> pulumi.Output[str]:
        """
        The name of the bucket.
        """
        return pulumi.get(self, "bucket")

    @property
    @pulumi.getter(name="kmsDataEncryption")
    def kms_data_encryption(self) -> pulumi.Output[Optional[str]]:
        """
        The algorithm used to encrypt objects. If this element is not specified, objects are encrypted by using AES256. This element is valid only when the value of SSEAlgorithm is set to KMS.
        """
        return pulumi.get(self, "kms_data_encryption")

    @property
    @pulumi.getter(name="kmsMasterKeyId")
    def kms_master_key_id(self) -> pulumi.Output[Optional[str]]:
        """
        The CMK ID that must be specified when SSEAlgorithm is set to KMS and a specified CMK is used for encryption. In other cases, this element must be set to null.
        """
        return pulumi.get(self, "kms_master_key_id")

    @property
    @pulumi.getter(name="sseAlgorithm")
    def sse_algorithm(self) -> pulumi.Output[str]:
        """
        The server-side encryption method. Valid Values: KMS, AES256.
        """
        return pulumi.get(self, "sse_algorithm")




# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities
from . import outputs

__all__ = [
    'GetEnterpriseProxyAccessesResult',
    'AwaitableGetEnterpriseProxyAccessesResult',
    'get_enterprise_proxy_accesses',
    'get_enterprise_proxy_accesses_output',
]

@pulumi.output_type
class GetEnterpriseProxyAccessesResult:
    """
    A collection of values returned by getEnterpriseProxyAccesses.
    """
    def __init__(__self__, accesses=None, enable_details=None, id=None, ids=None, output_file=None, proxy_id=None):
        if accesses and not isinstance(accesses, list):
            raise TypeError("Expected argument 'accesses' to be a list")
        pulumi.set(__self__, "accesses", accesses)
        if enable_details and not isinstance(enable_details, bool):
            raise TypeError("Expected argument 'enable_details' to be a bool")
        pulumi.set(__self__, "enable_details", enable_details)
        if id and not isinstance(id, str):
            raise TypeError("Expected argument 'id' to be a str")
        pulumi.set(__self__, "id", id)
        if ids and not isinstance(ids, list):
            raise TypeError("Expected argument 'ids' to be a list")
        pulumi.set(__self__, "ids", ids)
        if output_file and not isinstance(output_file, str):
            raise TypeError("Expected argument 'output_file' to be a str")
        pulumi.set(__self__, "output_file", output_file)
        if proxy_id and not isinstance(proxy_id, str):
            raise TypeError("Expected argument 'proxy_id' to be a str")
        pulumi.set(__self__, "proxy_id", proxy_id)

    @property
    @pulumi.getter
    def accesses(self) -> Sequence['outputs.GetEnterpriseProxyAccessesAccessResult']:
        """
        A list of Proxy Access Entries. Each element contains the following attributes:
        """
        return pulumi.get(self, "accesses")

    @property
    @pulumi.getter(name="enableDetails")
    def enable_details(self) -> Optional[bool]:
        return pulumi.get(self, "enable_details")

    @property
    @pulumi.getter
    def id(self) -> str:
        """
        The provider-assigned unique ID for this managed resource.
        """
        return pulumi.get(self, "id")

    @property
    @pulumi.getter
    def ids(self) -> Sequence[str]:
        """
        A list of Proxy Access IDs.
        """
        return pulumi.get(self, "ids")

    @property
    @pulumi.getter(name="outputFile")
    def output_file(self) -> Optional[str]:
        return pulumi.get(self, "output_file")

    @property
    @pulumi.getter(name="proxyId")
    def proxy_id(self) -> str:
        """
        The ID of the security agent.
        """
        return pulumi.get(self, "proxy_id")


class AwaitableGetEnterpriseProxyAccessesResult(GetEnterpriseProxyAccessesResult):
    # pylint: disable=using-constant-test
    def __await__(self):
        if False:
            yield self
        return GetEnterpriseProxyAccessesResult(
            accesses=self.accesses,
            enable_details=self.enable_details,
            id=self.id,
            ids=self.ids,
            output_file=self.output_file,
            proxy_id=self.proxy_id)


def get_enterprise_proxy_accesses(enable_details: Optional[bool] = None,
                                  ids: Optional[Sequence[str]] = None,
                                  output_file: Optional[str] = None,
                                  proxy_id: Optional[str] = None,
                                  opts: Optional[pulumi.InvokeOptions] = None) -> AwaitableGetEnterpriseProxyAccessesResult:
    """
    This data source provides DMS Enterprise Proxy Access available to the user.[What is Proxy Access](https://next.api.alibabacloud.com/document/dms-enterprise/2018-11-01/CreateProxyAccess)

    > **NOTE:** Available since v1.195.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_enterprise_proxy_access = alicloud.dms.EnterpriseProxyAccess("default",
        indep_password="PASSWORD-DEMO",
        proxy_id="1881",
        indep_account="dmstest",
        user_id="104442")
    default = alicloud.dms.get_enterprise_proxy_accesses_output(ids=[default_enterprise_proxy_access.id],
        proxy_id="1881")
    pulumi.export("alicloudDmsProxyAccesesExampleId", default.accesses[0].id)
    ```


    :param Sequence[str] ids: A list of Proxy Access IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str proxy_id: The ID of the security agent.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['proxyId'] = proxy_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke('alicloud:dms/getEnterpriseProxyAccesses:getEnterpriseProxyAccesses', __args__, opts=opts, typ=GetEnterpriseProxyAccessesResult).value

    return AwaitableGetEnterpriseProxyAccessesResult(
        accesses=pulumi.get(__ret__, 'accesses'),
        enable_details=pulumi.get(__ret__, 'enable_details'),
        id=pulumi.get(__ret__, 'id'),
        ids=pulumi.get(__ret__, 'ids'),
        output_file=pulumi.get(__ret__, 'output_file'),
        proxy_id=pulumi.get(__ret__, 'proxy_id'))
def get_enterprise_proxy_accesses_output(enable_details: Optional[pulumi.Input[Optional[bool]]] = None,
                                         ids: Optional[pulumi.Input[Optional[Sequence[str]]]] = None,
                                         output_file: Optional[pulumi.Input[Optional[str]]] = None,
                                         proxy_id: Optional[pulumi.Input[str]] = None,
                                         opts: Optional[pulumi.InvokeOptions] = None) -> pulumi.Output[GetEnterpriseProxyAccessesResult]:
    """
    This data source provides DMS Enterprise Proxy Access available to the user.[What is Proxy Access](https://next.api.alibabacloud.com/document/dms-enterprise/2018-11-01/CreateProxyAccess)

    > **NOTE:** Available since v1.195.0.

    ## Example Usage

    ```python
    import pulumi
    import pulumi_alicloud as alicloud

    default_enterprise_proxy_access = alicloud.dms.EnterpriseProxyAccess("default",
        indep_password="PASSWORD-DEMO",
        proxy_id="1881",
        indep_account="dmstest",
        user_id="104442")
    default = alicloud.dms.get_enterprise_proxy_accesses_output(ids=[default_enterprise_proxy_access.id],
        proxy_id="1881")
    pulumi.export("alicloudDmsProxyAccesesExampleId", default.accesses[0].id)
    ```


    :param Sequence[str] ids: A list of Proxy Access IDs.
    :param str output_file: File name where to save data source results (after running `pulumi preview`).
    :param str proxy_id: The ID of the security agent.
    """
    __args__ = dict()
    __args__['enableDetails'] = enable_details
    __args__['ids'] = ids
    __args__['outputFile'] = output_file
    __args__['proxyId'] = proxy_id
    opts = pulumi.InvokeOptions.merge(_utilities.get_invoke_opts_defaults(), opts)
    __ret__ = pulumi.runtime.invoke_output('alicloud:dms/getEnterpriseProxyAccesses:getEnterpriseProxyAccesses', __args__, opts=opts, typ=GetEnterpriseProxyAccessesResult)
    return __ret__.apply(lambda __response__: GetEnterpriseProxyAccessesResult(
        accesses=pulumi.get(__response__, 'accesses'),
        enable_details=pulumi.get(__response__, 'enable_details'),
        id=pulumi.get(__response__, 'id'),
        ids=pulumi.get(__response__, 'ids'),
        output_file=pulumi.get(__response__, 'output_file'),
        proxy_id=pulumi.get(__response__, 'proxy_id')))



# coding=utf-8
# *** WARNING: this file was generated by the Pulumi Terraform Bridge (tfgen) Tool. ***
# *** Do not edit by hand unless you're certain you know what you are doing! ***

import copy
import warnings
import sys
import pulumi
import pulumi.runtime
from typing import Any, Mapping, Optional, Sequence, Union, overload
if sys.version_info >= (3, 11):
    from typing import NotRequired, TypedDict, TypeAlias
else:
    from typing_extensions import NotRequired, TypedDict, TypeAlias
from .. import _utilities

__all__ = ['EipArgs', 'Eip']

@pulumi.input_type
class EipArgs:
    def __init__(__self__, *,
                 ens_region_id: pulumi.Input[str],
                 internet_charge_type: pulumi.Input[str],
                 payment_type: pulumi.Input[str],
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 eip_name: Optional[pulumi.Input[str]] = None,
                 isp: Optional[pulumi.Input[str]] = None):
        """
        The set of arguments for constructing a Eip resource.
        :param pulumi.Input[str] ens_region_id: Ens node ID.
        :param pulumi.Input[str] internet_charge_type: Billing type of the EIP instance. Valid value: 95bandwidthbymonth.
        :param pulumi.Input[str] payment_type: The billing type of the EIP instanceValue: PayAsYouGo.
        :param pulumi.Input[int] bandwidth: The peak bandwidth of the EIP to be specified.Rules:Default value: 5, value range: 5~10000, unit: Mbps. Example value: 5.
        :param pulumi.Input[str] description: The description of the EIP.
        :param pulumi.Input[str] eip_name: Name of the EIP instance.
        :param pulumi.Input[str] isp: Internet service provider, if not filled in, it will be assigned according to the default rules.
        """
        pulumi.set(__self__, "ens_region_id", ens_region_id)
        pulumi.set(__self__, "internet_charge_type", internet_charge_type)
        pulumi.set(__self__, "payment_type", payment_type)
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if eip_name is not None:
            pulumi.set(__self__, "eip_name", eip_name)
        if isp is not None:
            pulumi.set(__self__, "isp", isp)

    @property
    @pulumi.getter(name="ensRegionId")
    def ens_region_id(self) -> pulumi.Input[str]:
        """
        Ens node ID.
        """
        return pulumi.get(self, "ens_region_id")

    @ens_region_id.setter
    def ens_region_id(self, value: pulumi.Input[str]):
        pulumi.set(self, "ens_region_id", value)

    @property
    @pulumi.getter(name="internetChargeType")
    def internet_charge_type(self) -> pulumi.Input[str]:
        """
        Billing type of the EIP instance. Valid value: 95bandwidthbymonth.
        """
        return pulumi.get(self, "internet_charge_type")

    @internet_charge_type.setter
    def internet_charge_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "internet_charge_type", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Input[str]:
        """
        The billing type of the EIP instanceValue: PayAsYouGo.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: pulumi.Input[str]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        The peak bandwidth of the EIP to be specified.Rules:Default value: 5, value range: 5~10000, unit: Mbps. Example value: 5.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the EIP.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="eipName")
    def eip_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the EIP instance.
        """
        return pulumi.get(self, "eip_name")

    @eip_name.setter
    def eip_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eip_name", value)

    @property
    @pulumi.getter
    def isp(self) -> Optional[pulumi.Input[str]]:
        """
        Internet service provider, if not filled in, it will be assigned according to the default rules.
        """
        return pulumi.get(self, "isp")

    @isp.setter
    def isp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isp", value)


@pulumi.input_type
class _EipState:
    def __init__(__self__, *,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 create_time: Optional[pulumi.Input[str]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 eip_name: Optional[pulumi.Input[str]] = None,
                 ens_region_id: Optional[pulumi.Input[str]] = None,
                 internet_charge_type: Optional[pulumi.Input[str]] = None,
                 isp: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 status: Optional[pulumi.Input[str]] = None):
        """
        Input properties used for looking up and filtering Eip resources.
        :param pulumi.Input[int] bandwidth: The peak bandwidth of the EIP to be specified.Rules:Default value: 5, value range: 5~10000, unit: Mbps. Example value: 5.
        :param pulumi.Input[str] create_time: The creation time of the EIP instance.
        :param pulumi.Input[str] description: The description of the EIP.
        :param pulumi.Input[str] eip_name: Name of the EIP instance.
        :param pulumi.Input[str] ens_region_id: Ens node ID.
        :param pulumi.Input[str] internet_charge_type: Billing type of the EIP instance. Valid value: 95bandwidthbymonth.
        :param pulumi.Input[str] isp: Internet service provider, if not filled in, it will be assigned according to the default rules.
        :param pulumi.Input[str] payment_type: The billing type of the EIP instanceValue: PayAsYouGo.
        :param pulumi.Input[str] status: The status of the EIP instance.Rules:Associating: bindingUnassociating: UnbindingInUse: AssignedAvailable: AvailableCreating: CreatingReleasing: Releasing.
        """
        if bandwidth is not None:
            pulumi.set(__self__, "bandwidth", bandwidth)
        if create_time is not None:
            pulumi.set(__self__, "create_time", create_time)
        if description is not None:
            pulumi.set(__self__, "description", description)
        if eip_name is not None:
            pulumi.set(__self__, "eip_name", eip_name)
        if ens_region_id is not None:
            pulumi.set(__self__, "ens_region_id", ens_region_id)
        if internet_charge_type is not None:
            pulumi.set(__self__, "internet_charge_type", internet_charge_type)
        if isp is not None:
            pulumi.set(__self__, "isp", isp)
        if payment_type is not None:
            pulumi.set(__self__, "payment_type", payment_type)
        if status is not None:
            pulumi.set(__self__, "status", status)

    @property
    @pulumi.getter
    def bandwidth(self) -> Optional[pulumi.Input[int]]:
        """
        The peak bandwidth of the EIP to be specified.Rules:Default value: 5, value range: 5~10000, unit: Mbps. Example value: 5.
        """
        return pulumi.get(self, "bandwidth")

    @bandwidth.setter
    def bandwidth(self, value: Optional[pulumi.Input[int]]):
        pulumi.set(self, "bandwidth", value)

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> Optional[pulumi.Input[str]]:
        """
        The creation time of the EIP instance.
        """
        return pulumi.get(self, "create_time")

    @create_time.setter
    def create_time(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "create_time", value)

    @property
    @pulumi.getter
    def description(self) -> Optional[pulumi.Input[str]]:
        """
        The description of the EIP.
        """
        return pulumi.get(self, "description")

    @description.setter
    def description(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "description", value)

    @property
    @pulumi.getter(name="eipName")
    def eip_name(self) -> Optional[pulumi.Input[str]]:
        """
        Name of the EIP instance.
        """
        return pulumi.get(self, "eip_name")

    @eip_name.setter
    def eip_name(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "eip_name", value)

    @property
    @pulumi.getter(name="ensRegionId")
    def ens_region_id(self) -> Optional[pulumi.Input[str]]:
        """
        Ens node ID.
        """
        return pulumi.get(self, "ens_region_id")

    @ens_region_id.setter
    def ens_region_id(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "ens_region_id", value)

    @property
    @pulumi.getter(name="internetChargeType")
    def internet_charge_type(self) -> Optional[pulumi.Input[str]]:
        """
        Billing type of the EIP instance. Valid value: 95bandwidthbymonth.
        """
        return pulumi.get(self, "internet_charge_type")

    @internet_charge_type.setter
    def internet_charge_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "internet_charge_type", value)

    @property
    @pulumi.getter
    def isp(self) -> Optional[pulumi.Input[str]]:
        """
        Internet service provider, if not filled in, it will be assigned according to the default rules.
        """
        return pulumi.get(self, "isp")

    @isp.setter
    def isp(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "isp", value)

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> Optional[pulumi.Input[str]]:
        """
        The billing type of the EIP instanceValue: PayAsYouGo.
        """
        return pulumi.get(self, "payment_type")

    @payment_type.setter
    def payment_type(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "payment_type", value)

    @property
    @pulumi.getter
    def status(self) -> Optional[pulumi.Input[str]]:
        """
        The status of the EIP instance.Rules:Associating: bindingUnassociating: UnbindingInUse: AssignedAvailable: AvailableCreating: CreatingReleasing: Releasing.
        """
        return pulumi.get(self, "status")

    @status.setter
    def status(self, value: Optional[pulumi.Input[str]]):
        pulumi.set(self, "status", value)


class Eip(pulumi.CustomResource):
    @overload
    def __init__(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 eip_name: Optional[pulumi.Input[str]] = None,
                 ens_region_id: Optional[pulumi.Input[str]] = None,
                 internet_charge_type: Optional[pulumi.Input[str]] = None,
                 isp: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        """
        Provides a ENS Eip resource. Edge elastic public network IP. When you use it for the first time, please contact the product classmates to add a resource whitelist.

        For information about ENS Eip and how to use it, see [What is Eip](https://www.alibabacloud.com/help/en/ens/developer-reference/api-createeipinstance).

        > **NOTE:** Available since v1.213.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.ens.Eip("default",
            description="EipDescription_autotest",
            bandwidth=5,
            isp="cmcc",
            payment_type="PayAsYouGo",
            ens_region_id="cn-chenzhou-telecom_unicom_cmcc",
            eip_name=name,
            internet_charge_type="95BandwidthByMonth")
        ```

        ## Import

        ENS Eip can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ens/eip:Eip example <id>
        ```

        :param str resource_name: The name of the resource.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] bandwidth: The peak bandwidth of the EIP to be specified.Rules:Default value: 5, value range: 5~10000, unit: Mbps. Example value: 5.
        :param pulumi.Input[str] description: The description of the EIP.
        :param pulumi.Input[str] eip_name: Name of the EIP instance.
        :param pulumi.Input[str] ens_region_id: Ens node ID.
        :param pulumi.Input[str] internet_charge_type: Billing type of the EIP instance. Valid value: 95bandwidthbymonth.
        :param pulumi.Input[str] isp: Internet service provider, if not filled in, it will be assigned according to the default rules.
        :param pulumi.Input[str] payment_type: The billing type of the EIP instanceValue: PayAsYouGo.
        """
        ...
    @overload
    def __init__(__self__,
                 resource_name: str,
                 args: EipArgs,
                 opts: Optional[pulumi.ResourceOptions] = None):
        """
        Provides a ENS Eip resource. Edge elastic public network IP. When you use it for the first time, please contact the product classmates to add a resource whitelist.

        For information about ENS Eip and how to use it, see [What is Eip](https://www.alibabacloud.com/help/en/ens/developer-reference/api-createeipinstance).

        > **NOTE:** Available since v1.213.0.

        ## Example Usage

        Basic Usage

        ```python
        import pulumi
        import pulumi_alicloud as alicloud

        config = pulumi.Config()
        name = config.get("name")
        if name is None:
            name = "terraform-example"
        default = alicloud.ens.Eip("default",
            description="EipDescription_autotest",
            bandwidth=5,
            isp="cmcc",
            payment_type="PayAsYouGo",
            ens_region_id="cn-chenzhou-telecom_unicom_cmcc",
            eip_name=name,
            internet_charge_type="95BandwidthByMonth")
        ```

        ## Import

        ENS Eip can be imported using the id, e.g.

        ```sh
        $ pulumi import alicloud:ens/eip:Eip example <id>
        ```

        :param str resource_name: The name of the resource.
        :param EipArgs args: The arguments to use to populate this resource's properties.
        :param pulumi.ResourceOptions opts: Options for the resource.
        """
        ...
    def __init__(__self__, resource_name: str, *args, **kwargs):
        resource_args, opts = _utilities.get_resource_args_opts(EipArgs, pulumi.ResourceOptions, *args, **kwargs)
        if resource_args is not None:
            __self__._internal_init(resource_name, opts, **resource_args.__dict__)
        else:
            __self__._internal_init(resource_name, *args, **kwargs)

    def _internal_init(__self__,
                 resource_name: str,
                 opts: Optional[pulumi.ResourceOptions] = None,
                 bandwidth: Optional[pulumi.Input[int]] = None,
                 description: Optional[pulumi.Input[str]] = None,
                 eip_name: Optional[pulumi.Input[str]] = None,
                 ens_region_id: Optional[pulumi.Input[str]] = None,
                 internet_charge_type: Optional[pulumi.Input[str]] = None,
                 isp: Optional[pulumi.Input[str]] = None,
                 payment_type: Optional[pulumi.Input[str]] = None,
                 __props__=None):
        opts = pulumi.ResourceOptions.merge(_utilities.get_resource_opts_defaults(), opts)
        if not isinstance(opts, pulumi.ResourceOptions):
            raise TypeError('Expected resource options to be a ResourceOptions instance')
        if opts.id is None:
            if __props__ is not None:
                raise TypeError('__props__ is only valid when passed in combination with a valid opts.id to get an existing resource')
            __props__ = EipArgs.__new__(EipArgs)

            __props__.__dict__["bandwidth"] = bandwidth
            __props__.__dict__["description"] = description
            __props__.__dict__["eip_name"] = eip_name
            if ens_region_id is None and not opts.urn:
                raise TypeError("Missing required property 'ens_region_id'")
            __props__.__dict__["ens_region_id"] = ens_region_id
            if internet_charge_type is None and not opts.urn:
                raise TypeError("Missing required property 'internet_charge_type'")
            __props__.__dict__["internet_charge_type"] = internet_charge_type
            __props__.__dict__["isp"] = isp
            if payment_type is None and not opts.urn:
                raise TypeError("Missing required property 'payment_type'")
            __props__.__dict__["payment_type"] = payment_type
            __props__.__dict__["create_time"] = None
            __props__.__dict__["status"] = None
        super(Eip, __self__).__init__(
            'alicloud:ens/eip:Eip',
            resource_name,
            __props__,
            opts)

    @staticmethod
    def get(resource_name: str,
            id: pulumi.Input[str],
            opts: Optional[pulumi.ResourceOptions] = None,
            bandwidth: Optional[pulumi.Input[int]] = None,
            create_time: Optional[pulumi.Input[str]] = None,
            description: Optional[pulumi.Input[str]] = None,
            eip_name: Optional[pulumi.Input[str]] = None,
            ens_region_id: Optional[pulumi.Input[str]] = None,
            internet_charge_type: Optional[pulumi.Input[str]] = None,
            isp: Optional[pulumi.Input[str]] = None,
            payment_type: Optional[pulumi.Input[str]] = None,
            status: Optional[pulumi.Input[str]] = None) -> 'Eip':
        """
        Get an existing Eip resource's state with the given name, id, and optional extra
        properties used to qualify the lookup.

        :param str resource_name: The unique name of the resulting resource.
        :param pulumi.Input[str] id: The unique provider ID of the resource to lookup.
        :param pulumi.ResourceOptions opts: Options for the resource.
        :param pulumi.Input[int] bandwidth: The peak bandwidth of the EIP to be specified.Rules:Default value: 5, value range: 5~10000, unit: Mbps. Example value: 5.
        :param pulumi.Input[str] create_time: The creation time of the EIP instance.
        :param pulumi.Input[str] description: The description of the EIP.
        :param pulumi.Input[str] eip_name: Name of the EIP instance.
        :param pulumi.Input[str] ens_region_id: Ens node ID.
        :param pulumi.Input[str] internet_charge_type: Billing type of the EIP instance. Valid value: 95bandwidthbymonth.
        :param pulumi.Input[str] isp: Internet service provider, if not filled in, it will be assigned according to the default rules.
        :param pulumi.Input[str] payment_type: The billing type of the EIP instanceValue: PayAsYouGo.
        :param pulumi.Input[str] status: The status of the EIP instance.Rules:Associating: bindingUnassociating: UnbindingInUse: AssignedAvailable: AvailableCreating: CreatingReleasing: Releasing.
        """
        opts = pulumi.ResourceOptions.merge(opts, pulumi.ResourceOptions(id=id))

        __props__ = _EipState.__new__(_EipState)

        __props__.__dict__["bandwidth"] = bandwidth
        __props__.__dict__["create_time"] = create_time
        __props__.__dict__["description"] = description
        __props__.__dict__["eip_name"] = eip_name
        __props__.__dict__["ens_region_id"] = ens_region_id
        __props__.__dict__["internet_charge_type"] = internet_charge_type
        __props__.__dict__["isp"] = isp
        __props__.__dict__["payment_type"] = payment_type
        __props__.__dict__["status"] = status
        return Eip(resource_name, opts=opts, __props__=__props__)

    @property
    @pulumi.getter
    def bandwidth(self) -> pulumi.Output[int]:
        """
        The peak bandwidth of the EIP to be specified.Rules:Default value: 5, value range: 5~10000, unit: Mbps. Example value: 5.
        """
        return pulumi.get(self, "bandwidth")

    @property
    @pulumi.getter(name="createTime")
    def create_time(self) -> pulumi.Output[str]:
        """
        The creation time of the EIP instance.
        """
        return pulumi.get(self, "create_time")

    @property
    @pulumi.getter
    def description(self) -> pulumi.Output[Optional[str]]:
        """
        The description of the EIP.
        """
        return pulumi.get(self, "description")

    @property
    @pulumi.getter(name="eipName")
    def eip_name(self) -> pulumi.Output[Optional[str]]:
        """
        Name of the EIP instance.
        """
        return pulumi.get(self, "eip_name")

    @property
    @pulumi.getter(name="ensRegionId")
    def ens_region_id(self) -> pulumi.Output[str]:
        """
        Ens node ID.
        """
        return pulumi.get(self, "ens_region_id")

    @property
    @pulumi.getter(name="internetChargeType")
    def internet_charge_type(self) -> pulumi.Output[str]:
        """
        Billing type of the EIP instance. Valid value: 95bandwidthbymonth.
        """
        return pulumi.get(self, "internet_charge_type")

    @property
    @pulumi.getter
    def isp(self) -> pulumi.Output[str]:
        """
        Internet service provider, if not filled in, it will be assigned according to the default rules.
        """
        return pulumi.get(self, "isp")

    @property
    @pulumi.getter(name="paymentType")
    def payment_type(self) -> pulumi.Output[str]:
        """
        The billing type of the EIP instanceValue: PayAsYouGo.
        """
        return pulumi.get(self, "payment_type")

    @property
    @pulumi.getter
    def status(self) -> pulumi.Output[str]:
        """
        The status of the EIP instance.Rules:Associating: bindingUnassociating: UnbindingInUse: AssignedAvailable: AvailableCreating: CreatingReleasing: Releasing.
        """
        return pulumi.get(self, "status")

